(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    211366,       5486]
NotebookOptionsPosition[    203592,       5247]
NotebookOutlinePosition[    203949,       5263]
CellTagsIndexPosition[    203906,       5260]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Governing Equations", "Chapter",
 CellChangeTimes->{{3.6687639588989973`*^9, 3.6687639633197613`*^9}}],

Cell["Conservation of mass", "Text",
 CellChangeTimes->{{3.668763969776509*^9, 3.668763974831957*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mass\[LetterSpace]conservation", " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["r", "2"]], 
     RowBox[{"Dt", "[", 
      RowBox[{
       RowBox[{"\[Rho]", " ", "u", " ", 
        SuperscriptBox["r", "2"]}], ",", "r"}], "]"}]}], "\[Equal]", "q"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6687639790441694`*^9, 3.6687639989340677`*^9}, 
   3.6687641746052504`*^9, {3.6687649374605317`*^9, 3.668764944178399*^9}, {
   3.6687650861607056`*^9, 3.6687650868435163`*^9}}],

Cell["Conservation of momentum", "Text",
 CellChangeTimes->{{3.668763994598537*^9, 3.6687640090259113`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"momentum\[LetterSpace]conservation", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", " ", "u", " ", 
      RowBox[{"Dt", "[", 
       RowBox[{"u", ",", "r"}], "]"}]}], "+", 
     RowBox[{"Dt", "[", 
      RowBox[{"p", ",", "r"}], "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "q"}], " ", "u"}], " ", "-", 
     RowBox[{
      FractionBox["GM", 
       SuperscriptBox["r", "2"]], "\[Rho]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6687640131599393`*^9, 3.668764036393896*^9}, 
   3.6687641772021728`*^9, {3.6687649485432005`*^9, 3.668764954932233*^9}, {
   3.6687650914316854`*^9, 3.6687650922418413`*^9}, {3.668765997907685*^9, 
   3.668765998127234*^9}}],

Cell["Conservation of energy", "Text",
 CellChangeTimes->{{3.6687640921827307`*^9, 3.6687640992962894`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"energy\[LetterSpace]conservation", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["r", "2"]], 
       RowBox[{"Dt", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], "\[Rho]", " ", "u", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], 
             SuperscriptBox["u", "2"]}], "+", 
            FractionBox[
             RowBox[{"\[Gamma]", " ", 
              RowBox[{"p", "/", "\[Rho]"}]}], 
             RowBox[{"\[Gamma]", "-", "1"}]]}], ")"}]}], ",", "r"}], "]"}]}], 
      "\[Equal]", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], "q", " ", 
        SuperscriptBox["vw", "2"]}], "-", 
       RowBox[{
        FractionBox["GM", 
         SuperscriptBox["r", "2"]], "\[Rho]", " ", "u"}]}]}], "/.", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.668764087953477*^9, 3.6687641788595877`*^9}, {
   3.668764345706439*^9, 3.668764355243804*^9}, {3.668764963179132*^9, 
   3.668764969656359*^9}, {3.668765095292961*^9, 3.6687650958013115`*^9}, {
   3.668765729327876*^9, 3.668765731474592*^9}, 3.668765873581442*^9, {
   3.668766065669073*^9, 3.668766065793408*^9}, {3.668767236709722*^9, 
   3.66876724207299*^9}, {3.6687674046942472`*^9, 3.6687674051113477`*^9}}],

Cell["Mass source term", "Text",
 CellChangeTimes->{{3.6687641806623597`*^9, 3.668764183940079*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mass\[LetterSpace]source", "=", 
   RowBox[{"DD", " ", 
    SuperscriptBox["r", 
     RowBox[{"-", "\[Eta]"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.66876418561959*^9, 3.6687641973998823`*^9}, {
  3.668764972921049*^9, 3.668764974767976*^9}, {3.6687650992665706`*^9, 
  3.668765099672615*^9}}],

Cell["Entropy conservation", "Text",
 CellChangeTimes->{{3.673002023515627*^9, 3.6730020297236633`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Dt", "[", 
   RowBox[{"s", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"s", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"Log", "[", "p", "]"}], "-", 
     RowBox[{"\[Gamma]", " ", 
      RowBox[{"Log", "[", "\[Rho]", "]"}]}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "mass\[LetterSpace]conservation", ",", 
        "momentum\[LetterSpace]conservation", ",", 
        "energy\[LetterSpace]conservation"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dt", "[", 
         RowBox[{"\[Rho]", ",", "r"}], "]"}], ",", 
        RowBox[{"Dt", "[", 
         RowBox[{"p", ",", "r"}], "]"}], ",", 
        RowBox[{"Dt", "[", 
         RowBox[{"u", ",", "r"}], "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Dt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", "p", "]"}], "-", 
      RowBox[{"\[Gamma]", " ", 
       RowBox[{"Log", "[", "\[Rho]", "]"}]}]}], ",", "r"}], "]"}], "\[Equal]",
    "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"entropy\[LetterSpace]conservation", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6730019150490775`*^9, 3.6730020186352816`*^9}}],

Cell["Reduction to Dimensionless variables", "Chapter",
 CellChangeTimes->{{3.6687642570232706`*^9, 3.668764263703038*^9}, 
   3.6714178224364386`*^9}],

Cell["Bondi radius", "Text",
 CellChangeTimes->{{3.66876525952707*^9, 3.6687652659150677`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bondi\[LetterSpace]radius", "=", 
   FractionBox["GM", 
    SuperscriptBox["vw", "2"]]}], ";"}]], "Input",
 CellChangeTimes->{{3.6687650165950966`*^9, 3.668765029156505*^9}, {
  3.6687657370534315`*^9, 3.668765739374258*^9}}],

Cell["Bondi density", "Text",
 CellChangeTimes->{{3.668765267193469*^9, 3.668765275110318*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DD", "*", 
   SuperscriptBox["bondi\[LetterSpace]radius", 
    RowBox[{"-", "\[Eta]"}]], "*", 
   RowBox[{"(", 
    RowBox[{"bondi\[LetterSpace]radius", "/", "vw"}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bondi\[LetterSpace]density", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6687651755501966`*^9, 3.668765233048208*^9}, {
  3.668765753768511*^9, 3.6687657545917015`*^9}}],

Cell["Dimensionless derivatives", "Chapter",
 CellChangeTimes->{{3.668765327274042*^9, 3.6687653319114013`*^9}, {
  3.6721417105187593`*^9, 3.67214172127973*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "mass\[LetterSpace]conservation", ",", 
    "momentum\[LetterSpace]conservation", ",", 
    "energy\[LetterSpace]conservation"}], "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"Dt", "[", 
      RowBox[{"z_", ",", "r"}], "]"}], "]"}], "\[Rule]", "  ", 
    FractionBox[
     RowBox[{"Dt", "[", 
      RowBox[{"z", ",", "\[Xi]"}], "]"}], 
     RowBox[{"Dt", "[", 
      RowBox[{"r", ",", "\[Xi]"}], "]"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"bondi\[LetterSpace]density", "*", 
     SuperscriptBox["vw", "2"], "*", "p"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", " ", 
    RowBox[{"bondi\[LetterSpace]density", " ", "\[Rho]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{"vw", " ", "u"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"bondi\[LetterSpace]radius", "*", "\[Xi]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Dt", "[", 
        RowBox[{"\[Rho]", ",", "\[Xi]"}], "]"}], ",", 
       RowBox[{"Dt", "[", 
        RowBox[{"u", ",", "\[Xi]"}], "]"}], ",", 
       RowBox[{"Dt", "[", 
        RowBox[{"p", ",", "\[Xi]"}], "]"}]}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dimles\[LetterSpace]derivs", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.668765366123577*^9, 3.6687655624578786`*^9}, {
  3.6687657138667507`*^9, 3.668765715626464*^9}, {3.668765764208308*^9, 
  3.6687659641789303`*^9}, {3.6687660757829747`*^9, 3.6687661017670984`*^9}}],

Cell["Integral expressions", "Chapter",
 CellChangeTimes->{{3.668766896376258*^9, 3.6687669038741555`*^9}}],

Cell["Mass conservation", "Text",
 CellChangeTimes->{{3.6687670815309935`*^9, 3.6687670875269747`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"mass\[LetterSpace]source", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "*", 
   SuperscriptBox["r", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"%", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", 
   RowBox[{"(", 
    RowBox[{"%", "/.", 
     RowBox[{"r", "\[Rule]", "rs"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", " ", "u", " ", 
    SuperscriptBox["r", "2"]}], "\[Equal]", "%"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", "=", 
  "%"}]}], "Input",
 CellChangeTimes->{{3.668766951343419*^9, 3.668767015140748*^9}, {
  3.668767058899786*^9, 3.668767074921403*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["r", "2"], " ", "u", " ", "\[Rho]"}], "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{"DD", " ", 
     SuperscriptBox["r", 
      RowBox[{"3", "-", "\[Eta]"}]]}], 
    RowBox[{"3", "-", "\[Eta]"}]], "-", 
   FractionBox[
    RowBox[{"DD", " ", 
     SuperscriptBox["rs", 
      RowBox[{"3", "-", "\[Eta]"}]]}], 
    RowBox[{"3", "-", "\[Eta]"}]]}]}]], "Output",
 CellChangeTimes->{
  3.668766959986367*^9, {3.668767002649479*^9, 3.6687670154084167`*^9}, {
   3.668767064160779*^9, 3.6687670758909917`*^9}, 3.6687672460576377`*^9, 
   3.668768288939129*^9, {3.6687683241177077`*^9, 3.668768332930148*^9}, 
   3.6687985489907017`*^9, 3.6688255550753927`*^9, 3.6688577240927076`*^9, 
   3.6688579627233686`*^9, 3.668861942104061*^9, 3.6695557593799124`*^9, 
   3.6695788060984716`*^9, 3.6714153863207407`*^9, 3.6721411101493473`*^9, 
   3.6721424500859175`*^9, 3.6725674599370804`*^9, 3.672833762956508*^9, 
   3.6731703142307477`*^9, 3.673170428441967*^9, 3.67348563106435*^9, {
   3.6734856800729504`*^9, 3.6734857028529167`*^9}, 3.6734857675670795`*^9, 
   3.680969537538454*^9, 3.7292537108137007`*^9, 3.729266626203332*^9}]
}, Open  ]],

Cell["Validation", "Text",
 CellChangeTimes->{{3.668767091404248*^9, 3.668767094757168*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dt", "[", 
   RowBox[{"%", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"mass\[LetterSpace]conservation", ",", 
      RowBox[{"Dt", "[", 
       RowBox[{"\[Rho]", ",", "_"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"rs", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.6687670964216022`*^9, 3.6687671778672733`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.6687670977211*^9, 3.668767178159015*^9}, 
   3.668767246086664*^9, 3.6687682889631786`*^9, {3.668768324140772*^9, 
   3.668768332955202*^9}, 3.6687985490147715`*^9, 3.668825555099456*^9, 
   3.668857724146882*^9, 3.668857962742463*^9, 3.6688619421230965`*^9, 
   3.669555759414003*^9, 3.6695788061385937`*^9, 3.671415386428774*^9, 
   3.672141110210003*^9, 3.6721424501315613`*^9, 3.672567465029541*^9, 
   3.672833766360568*^9, 3.6731703142628317`*^9, 3.6731704292560406`*^9, 
   3.673485631127528*^9, {3.6734856801010213`*^9, 3.6734857028910656`*^9}, 
   3.6734857676493177`*^9, 3.680969537673397*^9, 3.7292537109015083`*^9, 
   3.729266627412665*^9}]
}, Open  ]],

Cell["Energy conservation", "Text",
 CellChangeTimes->{{3.668767182074438*^9, 3.6687671860851345`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"GM", " ", "u", " ", "\[Rho]"}], 
    SuperscriptBox["r", "2"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
     "integral\[LetterSpace]mass\[LetterSpace]conservation", ",", "\[Rho]"}], 
     "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "*", 
   SuperscriptBox["r", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"%", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", 
   RowBox[{"(", 
    RowBox[{"%", "/.", 
     RowBox[{"r", "\[Rule]", "rs"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/", 
   RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["u", "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["vw", "2"]}], "+", 
    FractionBox[
     SuperscriptBox["c", "2"], 
     RowBox[{"\[Gamma]", "-", "1"}]]}], "\[Equal]", "%"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", "=", 
  "%"}]}], "Input",
 CellChangeTimes->{{3.668767264079526*^9, 3.6687672966601963`*^9}, {
  3.668767330466918*^9, 3.66876742161325*^9}, {3.6687674663552957`*^9, 
  3.6687674668907166`*^9}, {3.6687683218546777`*^9, 3.668768328951555*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    SuperscriptBox["u", "2"], "2"], "-", 
   FractionBox[
    SuperscriptBox["vw", "2"], "2"], "+", 
   FractionBox[
    SuperscriptBox["c", "2"], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Gamma]"}]]}], "\[Equal]", 
  FractionBox[
   RowBox[{"GM", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       SuperscriptBox["rs", "\[Eta]"]}], "+", 
      RowBox[{
       SuperscriptBox["r", 
        RowBox[{"1", "+", "\[Eta]"}]], " ", 
       SuperscriptBox["rs", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["r", "\[Eta]"], " ", 
       SuperscriptBox["rs", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "\[Eta]"]}], " ", 
       SuperscriptBox["rs", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.6687672741192417`*^9, 3.66876729770497*^9}, {
   3.6687673392222*^9, 3.668767384486642*^9}, 3.668767422631957*^9, 
   3.6687674673358994`*^9, 3.668768289035372*^9, {3.668768324219966*^9, 
   3.668768333002322*^9}, 3.668798549140102*^9, 3.6688255552267942`*^9, 
   3.6688577242852545`*^9, 3.6688579628474555`*^9, 3.6688619422329326`*^9, 
   3.6695557595820413`*^9, 3.669578806251412*^9, 3.671415386687612*^9, 
   3.6721411103603673`*^9, 3.672142450332156*^9, 3.6725674689298224`*^9, 
   3.6728337700770035`*^9, 3.6731703144234543`*^9, 3.6731704293773274`*^9, 
   3.673485631243853*^9, {3.6734856802193785`*^9, 3.6734857032323723`*^9}, 
   3.6734857678388357`*^9, 3.6809695378868227`*^9, 3.729253711097508*^9, 
   3.729266629507061*^9}]
}, Open  ]],

Cell["Validation", "Text",
 CellChangeTimes->{{3.668767429331777*^9, 3.6687674345205784`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "*", 
    RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "\[Equal]", 
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "*", 
    RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", " ", 
    SqrtBox[
     RowBox[{"\[Gamma]", " ", 
      RowBox[{"p", "/", "\[Rho]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dt", "[", 
   RowBox[{"%", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "mass\[LetterSpace]conservation", ",", "\[IndentingNewLine]", 
        "momentum\[LetterSpace]conservation", ",", "\[IndentingNewLine]", 
        "energy\[LetterSpace]conservation"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dt", "[", 
         RowBox[{"p", ",", "r"}], "]"}], ",", 
        RowBox[{"Dt", "[", 
         RowBox[{"\[Rho]", ",", "r"}], "]"}], ",", 
        RowBox[{"Dt", "[", 
         RowBox[{"u", ",", "r"}], "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"rs", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
     "integral\[LetterSpace]mass\[LetterSpace]conservation", ",", "\[Rho]"}], 
     "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.6687674365519805`*^9, 3.6687675435295424`*^9}, {
  3.668767718338745*^9, 3.6687677724998083`*^9}, {3.668767888929347*^9, 
  3.6687678972745533`*^9}, {3.6687683567962065`*^9, 3.668768370283124*^9}, {
  3.668769755530374*^9, 3.66876976814894*^9}, {3.668770436162488*^9, 
  3.668770461739529*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.6687674402157245`*^9, 3.6687674797769833`*^9}, {
   3.66876752428238*^9, 3.668767533628208*^9}, {3.668767722722363*^9, 
   3.668767773416211*^9}, 3.668767898153885*^9, 3.668768289304118*^9, {
   3.6687683248536477`*^9, 3.668768333067497*^9}, 3.6687683724598722`*^9, 
   3.6687697725145535`*^9, {3.668770441652088*^9, 3.6687704625035534`*^9}, 
   3.6687985492834797`*^9, 3.6688255553511252`*^9, 3.668857724517396*^9, 
   3.6688579629598026`*^9, 3.668861942426167*^9, 3.6695557597234306`*^9, 
   3.669578806392581*^9, 3.671415386825004*^9, 3.6721411105077724`*^9, 
   3.6721424504614897`*^9, 3.6725674723937263`*^9, 3.6728337732661324`*^9, 
   3.673170314559697*^9, 3.6731704294997215`*^9, 3.6734856314042296`*^9, {
   3.6734856803421974`*^9, 3.6734857033537016`*^9}, 3.6734857679581585`*^9, 
   3.680969538123263*^9, 3.7292537112547092`*^9, 3.7292666340498533`*^9}]
}, Open  ]],

Cell["Behaviour near the stagnation point", "Chapter",
 CellChangeTimes->{{3.673485014891776*^9, 3.6734850225821257`*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"r", "\[Rule]", "rs"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "%"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", 
      SqrtBox["c2"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "c2"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2\[LetterSpace]stagnation", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6734850247903566`*^9, 3.6734850810459795`*^9}, {
  3.673485140828609*^9, 3.6734851770952373`*^9}, {3.673485582371605*^9, 
  3.6734855832644835`*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "\[Rho]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "'"}], "[", "rs", "]"}], 
     RowBox[{"(", 
      RowBox[{"r", "-", "rs"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{"%", ",", 
    RowBox[{"r", "\[Rule]", "rs"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]\[LetterSpace]stagnation", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.67348522147912*^9, 3.6734852693580165`*^9}}],

Cell["Solutions without gravity ", "Chapter",
 CellChangeTimes->{{3.668770478362777*^9, 3.6687704846113663`*^9}, {
   3.6721423467653112`*^9, 3.672142355784148*^9}, 3.672145286775673*^9, {
   3.672145442060252*^9, 3.672145507466408*^9}, 3.6725674912296724`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hyperlink", "[", 
  RowBox[{
  "\"\<Chevalier & Clegg 1985\>\"", ",", 
   "\"\<http://adsabs.harvard.edu/abs/1985Natur.317...44C\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.672145494329982*^9, 3.6721455000349708`*^9}}],

Cell[BoxData[
 TagBox[
  ButtonBox[
   PaneSelectorBox[{False->"\<\"Chevalier & Clegg 1985\"\>", True->
    StyleBox["\<\"Chevalier & Clegg 1985\"\>", "HyperlinkActive"]}, Dynamic[
     CurrentValue["MouseOver"]],
    BaseStyle->{"Hyperlink"},
    FrameMargins->0,
    ImageSize->Automatic],
   BaseStyle->"Hyperlink",
   ButtonData->{
     URL["http://adsabs.harvard.edu/abs/1985Natur.317...44C"], None},
   ButtonNote->"http://adsabs.harvard.edu/abs/1985Natur.317...44C"],
  Annotation[#, "http://adsabs.harvard.edu/abs/1985Natur.317...44C", 
   "Hyperlink"]& ]], "Output",
 CellChangeTimes->{
  3.672145501057341*^9, 3.6725674765500793`*^9, 3.6728337802487717`*^9, 
   3.6731703145697236`*^9, 3.6731704296170683`*^9, 3.6734856324768667`*^9, {
   3.6734856807667007`*^9, 3.6734857037603645`*^9}, 3.673485768434456*^9, 
   3.680969539108321*^9, 3.729253711858086*^9, 3.729266642242845*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "mass\[LetterSpace]conservation", ",", 
    "momentum\[LetterSpace]conservation", ",", 
    "energy\[LetterSpace]conservation"}], "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"u", ",", "r"}], "]"}], "\[Rule]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"c", ",", "r"}], "]"}], "\[Rule]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", 
    RowBox[{"A", " ", 
     SuperscriptBox["r", 
      RowBox[{"1", "-", "\[Eta]"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"GM", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"A", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Alpha]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "u", ",", "c"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "3", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chevalier\[LetterSpace]clegg\[LetterSpace]prefactors", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"vw", ">", "0"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6687704955083523`*^9, 3.6687705185717278`*^9}, {
   3.6687706290746307`*^9, 3.668770810517183*^9}, {3.6687710072755513`*^9, 
   3.6687710475536957`*^9}, {3.672142362156973*^9, 3.672142366618497*^9}, {
   3.672142619880783*^9, 3.6721426223076234`*^9}, {3.672155282104535*^9, 
   3.6721552923448715`*^9}, {3.672196549621252*^9, 3.672196551415169*^9}, 
   3.672833786055198*^9}],

Cell["Validity domain", "Text",
 CellChangeTimes->{{3.672197898815124*^9, 3.6721979037881413`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"A", " ", "vw"}], "DD"], ")"}], "2"], ">", "0"}], "&&", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["u", "vw"], ")"}], "2"], ">", "0"}], "&&", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["c", "vw"], ")"}], "2"], ">", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "%", " ", "/.", " ", 
   "chevalier\[LetterSpace]clegg\[LetterSpace]prefactors"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Reduce", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"\[Gamma]", ">", "1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6721978277005415`*^9, 3.6721978790388155`*^9}}],

Cell[BoxData[
 RowBox[{"1", "<", "\[Eta]", "<", "3"}]], "Output",
 CellChangeTimes->{
  3.672197879352013*^9, 3.6725675033667727`*^9, 3.6728337891352053`*^9, 
   3.673170314897135*^9, 3.6731704301271*^9, 3.6734856333110647`*^9, {
   3.6734856813203278`*^9, 3.6734857042873783`*^9}, 3.673485768967991*^9, 
   3.680969539759478*^9, 3.729253712297573*^9, 3.729266649040904*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   FractionBox["u", "c"], "/.", 
   "chevalier\[LetterSpace]clegg\[LetterSpace]prefactors"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{
     RowBox[{"vw", ">", "0"}], "&&", 
     RowBox[{"\[Gamma]", ">", "1"}], "&&", 
     RowBox[{"\[Eta]", "\[Element]", "Reals"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"\[Gamma]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", "\[Eta]"}], ")"}]}], "+", "\[Eta]"}], 
    "\[Rule]", " ", "Q"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Q", ">", "0"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "chevalier\[LetterSpace]clegg\[LetterSpace]mach\[LetterSpace]number", "=", 
   "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.66877106008703*^9, 3.6687710814699087`*^9}, {
   3.668771871431357*^9, 3.6687718828326864`*^9}, {3.672142465796408*^9, 
   3.6721425038630457`*^9}, {3.672142686792*^9, 3.6721427294302998`*^9}, {
   3.6721451060119486`*^9, 3.6721451129341793`*^9}, 3.672833794589381*^9}],

Cell["Condition for supersonic flow at large distances", "Text",
 CellChangeTimes->{{3.668771098209325*^9, 3.668771115269681*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "chevalier\[LetterSpace]clegg\[LetterSpace]mach\[LetterSpace]number", "==", 
   "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Eta]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "\[Eta]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "chevalier\[LetterSpace]clegg\[LetterSpace]mach\[LetterSpace]sonic\
\[LetterSpace]\[Eta]", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.668771145917235*^9, 3.668771159252673*^9}, {
   3.6687718490868864`*^9, 3.668771890563218*^9}, {3.6688401077740154`*^9, 
   3.6688401315456314`*^9}, {3.672145092379204*^9, 3.672145138992611*^9}, 
   3.6728337996515274`*^9}],

Cell["Asymptotic behaviour when r->\[Infinity] when \[Eta]>3", "Chapter",
 CellChangeTimes->{{3.6725677326523457`*^9, 3.672567798099658*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"GM", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}], "+", 
        RowBox[{
         SuperscriptBox["r", 
          RowBox[{"1", "+", "\[Eta]"}]], " ", 
         SuperscriptBox["rs", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "\[Eta]"]}], " ", 
         SuperscriptBox["rs", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]], "\[Rule]", 
    FractionBox[
     RowBox[{"GM", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"0", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}], "+", 
        RowBox[{
         SuperscriptBox["r", 
          RowBox[{"1", "+", "\[Eta]"}]], " ", 
         SuperscriptBox["rs", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
        RowBox[{"0", 
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "\[Eta]"]}], " ", 
         SuperscriptBox["rs", "3"]}], "+", 
        RowBox[{"0", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "u"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ur\[Infinity]\[Eta]ge3", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6730777642176943`*^9, 3.6730778191698737`*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["r", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]], "-", 
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["rs", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]]}], "\[Rule]", " ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["rs", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", "ur\[Infinity]\[Eta]ge3"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "\[Rho]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]r\[Infinity]\[Eta]ge3", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6730778309572506`*^9, 3.6730778927376127`*^9}}],

Cell[BoxData[{
 RowBox[{"entropy\[LetterSpace]conservation", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "p", " ", "\[Gamma]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox["vw", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}], " ", "\[Rho]"}]}], "->", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["u", "2"], "+", 
       SuperscriptBox["vw", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}], " ", "\[Rho]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"c2", " ", 
     RowBox[{"\[Rho]", "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", "\[Rho]r\[Infinity]\[Eta]ge3"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"rs", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c2", "\[Rule]", 
    RowBox[{"c2", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c2", "[", "r", "]"}], "/.", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"c2", "[", "r", "]"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2r\[Infinity]\[Eta]ge3", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6730779124705205`*^9, 3.6730779852730045`*^9}, {
  3.6730780194515605`*^9, 3.673078098420581*^9}, {3.673078180377996*^9, 
  3.673078395188675*^9}, {3.6730805435313797`*^9, 3.6730805568075867`*^9}}],

Cell["\<\
Asymptotic for r -> 0, \[Eta] < 3 and \[Gamma] < 5/3\
\>", "Chapter",
 CellChangeTimes->{{3.6725712830743866`*^9, 3.6725712968157506`*^9}, {
  3.672571331871756*^9, 3.6725713350386715`*^9}, {3.6726168042233934`*^9, 
  3.6726168066087093`*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", 
   RowBox[{
    FractionBox[
     RowBox[{"GM", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}], "+", 
        RowBox[{
         SuperscriptBox["r", 
          RowBox[{"1", "+", "\[Eta]"}]], " ", 
         SuperscriptBox["rs", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "\[Eta]"]}], " ", 
         SuperscriptBox["rs", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]], "\[Rule]", " ", 
    FractionBox[
     RowBox[{"GM", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"0", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}], "+", 
        RowBox[{"0", 
         SuperscriptBox["r", 
          RowBox[{"1", "+", "\[Eta]"}]], " ", 
         SuperscriptBox["rs", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "\[Eta]"]}], " ", 
         SuperscriptBox["rs", "3"]}], "+", 
        RowBox[{"0", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"vw", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "u"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ur0\[Eta]le3\[Gamma]le53", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6734840783407726`*^9, 3.673484139545371*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["r", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]], "-", 
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["rs", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]]}], "\[Rule]", " ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["rs", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", "ur0\[Eta]le3\[Gamma]le53"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "\[Rho]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]r0\[Eta]le3\[Gamma]le53", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6734841450980625`*^9, 3.673484205033969*^9}}],

Cell[BoxData[{
 RowBox[{"entropy\[LetterSpace]conservation", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "p", " ", "\[Gamma]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["u", "2"], "+", 
           SuperscriptBox["vw", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}], " ", "\[Rho]"}]}], 
       ")"}]}], 
     RowBox[{"2", " ", "p", " ", "u", " ", "\[Rho]"}]], "\[Rule]", " ", 
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         SuperscriptBox["u", "2"], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}], " ", "\[Rho]"}], 
       ")"}]}], 
     RowBox[{"2", " ", "p", " ", "u", " ", "\[Rho]"}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{"c2", "/", "\[Gamma]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", " ", "\[Rho]r0\[Eta]le3\[Gamma]le53"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", "ur0\[Eta]le3\[Gamma]le53"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"rs", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c2", "\[Rule]", 
    RowBox[{"c2", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c2", "[", "r", "]"}], "/.", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{"c2", "[", "rs", "]"}], "\[Equal]", 
         "c2\[LetterSpace]stagnation"}]}], "}"}], ",", 
      RowBox[{"c2", "[", "r", "]"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2r0\[Eta]le3\[Gamma]le53", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6734842144662333`*^9, 3.6734842457174563`*^9}, {
  3.673484280470946*^9, 3.673484392148923*^9}, {3.673484422989356*^9, 
  3.6734845364313126`*^9}, {3.673484612176905*^9, 3.673484612574286*^9}, {
  3.6734847052904954`*^9, 3.6734847710707045`*^9}, {3.6734848984141073`*^9, 
  3.673484906537616*^9}, {3.6734855658153973`*^9, 3.673485612355567*^9}, {
  3.67348567064482*^9, 3.6734856919364977`*^9}, {3.6734857469510965`*^9, 
  3.6734857557505455`*^9}}],

Cell["Asymptotic for  r -> 0, \[Eta] < 3, and \[Gamma] == 5/3", "Chapter",
 CellChangeTimes->{{3.672616797342333*^9, 3.672616822767933*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", "/.", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"DD", " ", 
         SuperscriptBox["r", 
          RowBox[{"3", "-", "\[Eta]"}]]}], 
        RowBox[{"3", "-", "\[Eta]"}]], "-", 
       FractionBox[
        RowBox[{"DD", " ", 
         SuperscriptBox["rs", 
          RowBox[{"3", "-", "\[Eta]"}]]}], 
        RowBox[{"3", "-", "\[Eta]"}]]}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"0", 
        FractionBox[
         RowBox[{"DD", " ", 
          SuperscriptBox["r", 
           RowBox[{"3", "-", "\[Eta]"}]]}], 
         RowBox[{"3", "-", "\[Eta]"}]]}], "-", 
       FractionBox[
        RowBox[{"DD", " ", 
         SuperscriptBox["rs", 
          RowBox[{"3", "-", "\[Eta]"}]]}], 
        RowBox[{"3", "-", "\[Eta]"}]]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", "/.", 
     RowBox[{
      FractionBox[
       RowBox[{"GM", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}], "+", 
          RowBox[{
           SuperscriptBox["r", 
            RowBox[{"1", "+", "\[Eta]"}]], " ", 
           SuperscriptBox["rs", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["r", "\[Eta]"], " ", 
           SuperscriptBox["rs", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "\[Eta]"]}], " ", 
           SuperscriptBox["rs", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]], "\[Rule]", " ", 
      FractionBox[
       RowBox[{"GM", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}], "+", 
          RowBox[{"0", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", "\[Eta]"}]], " ", 
           SuperscriptBox["rs", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["r", "\[Eta]"], " ", 
           SuperscriptBox["rs", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "\[Eta]"]}], " ", 
           SuperscriptBox["rs", "3"]}], "+", 
          RowBox[{"0", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]]}]}], ",", 
    "\[IndentingNewLine]", "momentum\[LetterSpace]conservation"}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], "/", 
     SqrtBox["r"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", " ", 
    RowBox[{"\[Beta]", "/", 
     SqrtBox["r"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", " ", 
    RowBox[{"\[Rho]0", "/", 
     SuperscriptBox["r", 
      RowBox[{"3", "/", "2"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Gamma]", "\[Rule]", 
    RowBox[{"5", "/", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"vw", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Alpha]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Beta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Rho]0", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"\[Rho]0", ">", "0"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.672616825346052*^9, 3.672617162763088*^9}, 
   3.672833839086173*^9}],

Cell["Asymptotic for r -> 0, \[Eta] < 3 and \[Gamma] > 5/3", "Chapter",
 CellChangeTimes->{{3.672617286509698*^9, 3.6726173011781735`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", "/.", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"DD", " ", 
         SuperscriptBox["r", 
          RowBox[{"3", "-", "\[Eta]"}]]}], 
        RowBox[{"3", "-", "\[Eta]"}]], "-", 
       FractionBox[
        RowBox[{"DD", " ", 
         SuperscriptBox["rs", 
          RowBox[{"3", "-", "\[Eta]"}]]}], 
        RowBox[{"3", "-", "\[Eta]"}]]}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"0", 
        FractionBox[
         RowBox[{"DD", " ", 
          SuperscriptBox["r", 
           RowBox[{"3", "-", "\[Eta]"}]]}], 
         RowBox[{"3", "-", "\[Eta]"}]]}], "-", 
       FractionBox[
        RowBox[{"DD", " ", 
         SuperscriptBox["rs", 
          RowBox[{"3", "-", "\[Eta]"}]]}], 
        RowBox[{"3", "-", "\[Eta]"}]]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", "/.", 
     RowBox[{
      FractionBox[
       RowBox[{"GM", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}], "+", 
          RowBox[{
           SuperscriptBox["r", 
            RowBox[{"1", "+", "\[Eta]"}]], " ", 
           SuperscriptBox["rs", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["r", "\[Eta]"], " ", 
           SuperscriptBox["rs", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "\[Eta]"]}], " ", 
           SuperscriptBox["rs", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]], "\[Rule]", " ", 
      FractionBox[
       RowBox[{"GM", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}], "+", 
          RowBox[{"0", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", "\[Eta]"}]], " ", 
           SuperscriptBox["rs", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["r", "\[Eta]"], " ", 
           SuperscriptBox["rs", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "\[Eta]"]}], " ", 
           SuperscriptBox["rs", "3"]}], "+", 
          RowBox[{"0", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]]}]}], ",", 
    "\[IndentingNewLine]", "momentum\[LetterSpace]conservation"}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", " ", 
    SqrtBox["c2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2r0\[Eta]le3\[Gamma]ge53", "=", 
   RowBox[{"c2", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"%", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"vw", "\[Rule]", "0"}], ",", 
          RowBox[{"u", "\[Rule]", "0"}]}], "}"}]}], ",", "c2"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]r0\[Eta]le3\[Gamma]ge53", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", "r", "]"}], "/.", 
        RowBox[{
         RowBox[{"DSolve", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"%%", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"q", "\[Rule]", "0"}], ",", 
                   RowBox[{"u", "\[Rule]", "0"}], ",", 
                   RowBox[{"c2", "\[Rule]", "c2r0\[Eta]le3\[Gamma]ge53"}]}], 
                  "}"}]}], ")"}], "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Dt", "[", 
                   RowBox[{"GM", ",", "r"}], "]"}], "\[Rule]", "0"}], ",", 
                 RowBox[{
                  RowBox[{"Dt", "[", 
                   RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", 
                  "0"}]}], "}"}]}], "/.", 
              RowBox[{"\[Rho]", "\[Rule]", 
               RowBox[{"\[Rho]", "[", "r", "]"}]}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Rho]", "[", "rs", "]"}], "/.", 
                RowBox[{"r", "\[Rule]", "rs"}]}], ")"}], "\[Equal]", 
              "\[Rho]st"}]}], "}"}], ",", 
           RowBox[{"\[Rho]", "[", "r", "]"}], ",", "r"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"\[Gamma]", ">", "1"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%%%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{"\[Rho]", "\[Rule]", "\[Rho]r0\[Eta]le3\[Gamma]ge53"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "u"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ur0\[Eta]le3\[Gamma]ge53", "=", 
   RowBox[{"Simplify", "[", "%", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.672617311801629*^9, 3.672617424873517*^9}, {
  3.6726174572136793`*^9, 3.6726175670273476`*^9}, {3.672617742213368*^9, 
  3.6726179087385893`*^9}}],

Cell["Asymptotic for r -> 0, \[Eta]>3", "Chapter",
 CellChangeTimes->{{3.6726191860734625`*^9, 3.672619202540662*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "integral\[LetterSpace]energy\[LetterSpace]conservation", ",", 
    "integral\[LetterSpace]mass\[LetterSpace]conservation", ",", 
    "momentum\[LetterSpace]conservation"}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["r", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]], "-", 
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["rs", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]]}], "->", 
    RowBox[{
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["r", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]], "-", 
     RowBox[{
      FractionBox[
       RowBox[{"DD", " ", 
        SuperscriptBox["rs", 
         RowBox[{"3", "-", "\[Eta]"}]]}], 
       RowBox[{"3", "-", "\[Eta]"}]], "0"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    FractionBox[
     RowBox[{"GM", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}], "+", 
        RowBox[{
         SuperscriptBox["r", 
          RowBox[{"1", "+", "\[Eta]"}]], " ", 
         SuperscriptBox["rs", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "\[Eta]"]}], " ", 
         SuperscriptBox["rs", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]], "->", 
    FractionBox[
     RowBox[{"GM", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}], "+", 
        RowBox[{"0", 
         SuperscriptBox["r", 
          RowBox[{"1", "+", "\[Eta]"}]], " ", 
         SuperscriptBox["rs", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}], "-", 
        RowBox[{"0", 
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]}], ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0"}], 
         SuperscriptBox["r", "\[Eta]"], " ", 
         SuperscriptBox["rs", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["rs", "\[Eta]"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Eta]"}], ")"}]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", 
    SqrtBox["c2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    SuperscriptBox["vw", "2"], "\[Rule]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{"c2", "/", "\[Gamma]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{"-", 
     SqrtBox[
      RowBox[{"\[Alpha]", "/", "r"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c2", "\[Rule]", " ", 
    RowBox[{"\[Beta]", "/", "r"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Alpha]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Beta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", "\[Rho]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Alpha]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"%", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"%", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      FractionBox["\[Alpha]", "r"]], ",", 
     FractionBox["\[Beta]", "r"]}], "}"}], "/.", "%"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur0\[Eta]ge3", "=", 
     RowBox[{"%", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ",", 
    RowBox[{"c2r0\[Eta]ge3", " ", "=", " ", 
     RowBox[{"%", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ";"}]}], "Input",
 CellChangeTimes->{{3.673317548628742*^9, 3.6733176526753254`*^9}, {
   3.67331768279963*^9, 3.673317737535782*^9}, {3.673317781537665*^9, 
   3.673317830639889*^9}, 3.673399071646036*^9, {3.6733991408746853`*^9, 
   3.673399189697482*^9}, {3.673502881540258*^9, 3.6735029791887407`*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["r", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]], "-", 
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["rs", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]]}], "->", 
    RowBox[{
     FractionBox[
      RowBox[{"DD", " ", 
       SuperscriptBox["r", 
        RowBox[{"3", "-", "\[Eta]"}]]}], 
      RowBox[{"3", "-", "\[Eta]"}]], "-", 
     RowBox[{"0", 
      FractionBox[
       RowBox[{"DD", " ", 
        SuperscriptBox["rs", 
         RowBox[{"3", "-", "\[Eta]"}]]}], 
       RowBox[{"3", "-", "\[Eta]"}]]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "\[Rho]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"u", "\[Rule]", "ur0\[Eta]ge3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]r0\[Eta]ge3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{
      RowBox[{"r", ">", "0"}], "&&", 
      RowBox[{"\[Eta]", ">", "3"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6733991925964594`*^9, 3.673399261693141*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SuperscriptBox["ur0\[Eta]ge3", "2"], "/", "c2r0\[Eta]ge3"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "<", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Reduce", "[", 
     RowBox[{"%", ",", "\[Eta]", ",", "Reals"}], "]"}], ",", 
    RowBox[{
     RowBox[{"\[Gamma]", ">", "1"}], "&&", 
     RowBox[{"\[Eta]", ">", "3"}], "&&", 
     RowBox[{"2", ">", "\[Gamma]", ">", 
      RowBox[{"5", "/", "3"}]}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", "%", "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.680971920965057*^9, 3.680972034198542*^9}, {
   3.680972069327078*^9, 3.680972102385994*^9}, 3.680972157923724*^9, {
   3.681003330266824*^9, 3.681003334023335*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "6"}], "+", "\[Eta]"}], ")"}]}], "+", 
   RowBox[{"2", " ", "\[Eta]"}]}], "<", 
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.6809719353064337`*^9, 3.680972034582189*^9}, {
   3.6809720702082644`*^9, 3.6809721028109217`*^9}, 3.680972158446933*^9, 
   3.6810033346231213`*^9, 3.7292537149565573`*^9}],

Cell["\\gamma  (\\eta -6)+2 \\eta <\\gamma ^2 (\\eta -3)+1", "Output",
 CellChangeTimes->{{3.6809719353064337`*^9, 3.680972034582189*^9}, {
   3.6809720702082644`*^9, 3.6809721028109217`*^9}, 3.680972158446933*^9, 
   3.6810033346231213`*^9, 3.729253714988057*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ur0\[Eta]ge3", "/", "vw"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"\[Xi]", " ", "bondi\[LetterSpace]radius"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"vw", ">", "0"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.681002838574195*^9, 3.6810028410214777`*^9}, {
  3.681002871548746*^9, 3.6810029770320597`*^9}}],

Cell["\<\
\\sqrt{\\frac{-6 \\gamma +4 \\eta -2}{(\\eta -2) \\xi  (\\gamma  (2 \\eta \
-9)+2 \\eta -1)}}\
\>", "Output",
 CellChangeTimes->{
  3.681002841544829*^9, 3.681002908798318*^9, {3.681002957091516*^9, 
   3.681002977496443*^9}, 3.729253715270686*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c2r0\[Eta]ge3", "/", 
   SuperscriptBox["vw", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"bondi\[LetterSpace]radius", " ", "\[Xi]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.6810031014694138`*^9, 3.681003130848572*^9}}],

Cell["\<\
\\frac{2 (\\gamma -1) \\gamma  (\\eta -3)}{(\\eta -2) \\xi  (\\gamma  (2 \
\\eta -9)+2 \\eta -1)}\
\>", "Output",
 CellChangeTimes->{{3.68100310559324*^9, 3.6810031325662537`*^9}, 
   3.7292537153269*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SuperscriptBox["ur0\[Eta]ge3", "2"], "/", "c2r0\[Eta]ge3"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.681003245862866*^9, 3.681003274041498*^9}}],

Cell["\\frac{-3 \\gamma +2 \\eta -1}{(\\gamma -1) \\gamma  (\\eta -3)}", \
"Output",
 CellChangeTimes->{{3.681003261026939*^9, 3.6810032743950653`*^9}, 
   3.72925371538411*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SuperscriptBox["\[Rho]r0\[Eta]ge3", "2"], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/", 
   SuperscriptBox["bondi\[LetterSpace]density", "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"\[Xi]", " ", "bondi\[LetterSpace]radius"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.681003765802602*^9, 3.681003848412359*^9}}],

Cell["\<\
\\frac{(\\eta -2) (\\gamma  (2 \\eta -9)+2 \\eta -1) \\xi ^{3-2 \\eta }}{2 \
(\\eta -3)^2 (-3 \\gamma +2 \\eta -1)}\
\>", "Output",
 CellChangeTimes->{{3.681003800324821*^9, 3.681003848732107*^9}, 
   3.729253715438795*^9}]
}, Open  ]],

Cell["Hydrostatic solution", "Chapter",
 CellChangeTimes->{{3.671417870241145*^9, 3.6714178759370837`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", "/.", 
   RowBox[{"u", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", 
   RowBox[{"c", "\[Rule]", 
    SqrtBox["c2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "c2"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2\[LetterSpace]hydrostatic", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.672625797050168*^9, 3.672625827666681*^9}}],

Cell[BoxData[{
 RowBox[{"momentum\[LetterSpace]conservation", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"c2", " ", 
     RowBox[{"\[Rho]", "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c2", "\[Rule]", " ", "c2\[LetterSpace]hydrostatic"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"\[Eta]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"rs", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqn\[LetterSpace]\[Rho]\[LetterSpace]hydrostatic", "=", "%"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.672625832846236*^9, 3.672625855805627*^9}, {
  3.6726259145896807`*^9, 3.6726259729227962`*^9}, {3.672626010013398*^9, 
  3.6726260102762566`*^9}}],

Cell["\<\
This equation admits a simple analytic solution only for specific values of \
\[Eta]\
\>", "Text",
 CellChangeTimes->{{3.672625976485639*^9, 3.6726260013427663`*^9}}],

Cell[BoxData[{
 RowBox[{"eqn\[LetterSpace]\[Rho]\[LetterSpace]hydrostatic", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", 
    RowBox[{"5", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"Dt", "[", 
     RowBox[{"\[Rho]", ",", "r"}], "]"}], "\[Rho]"], "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Dt", "[", 
       RowBox[{"\[Rho]", ",", "r"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"%", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Exp", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]\[LetterSpace]hydrostatic\[LetterSpace]\[Eta]52", "=", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "%"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6726260024079466`*^9, 3.6726260899428*^9}, {
  3.6726262073324175`*^9, 3.6726262485755315`*^9}, {3.6726263929290867`*^9, 
  3.6726264310399504`*^9}, {3.672628321125143*^9, 3.672628333659974*^9}}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]mass\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", 
    RowBox[{"5", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
   "\[Rho]", "\[Rule]", " ", 
    "\[Rho]\[LetterSpace]hydrostatic\[LetterSpace]\[Eta]52"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "u"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u\[LetterSpace]hydrostatic\[LetterSpace]\[Eta]52", "=", "%"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.672626251791156*^9, 3.6726263622963324`*^9}, {
  3.6726283809539595`*^9, 3.672628387618561*^9}, {3.6726284276301136`*^9, 
  3.672628450159799*^9}, {3.6726284848301096`*^9, 3.6726285354092417`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eqn\[LetterSpace]\[Rho]\[LetterSpace]hydrostatic", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", 
    RowBox[{"\[Rho]", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "r", "]"}], "/.", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"\[Rho]", "[", "r", "]"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.673172076692189*^9, 3.6731721451049623`*^9}, {
  3.6731723123020897`*^9, 3.673172379930444*^9}, {3.673172548934945*^9, 
  3.6731725511824565`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", "r", "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"GM", " ", "r"}], "-", 
          RowBox[{"GM", " ", "rs"}], "-", 
          RowBox[{"r", " ", "rs", " ", 
           SuperscriptBox["vw", "2"]}]}], "]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Gamma]"}]]}]], " ", 
  RowBox[{"C", "[", "1", "]"}]}]], "Output",
 CellChangeTimes->{
  3.673172380238368*^9, 3.673173074542346*^9, 3.673485636357399*^9, {
   3.6734856840155053`*^9, 3.673485707029574*^9}, 3.6734857722887697`*^9, 
   3.6809695435967827`*^9, 3.729253715899741*^9}]
}, Open  ]],

Cell["Secular Analytic solution", "Chapter",
 CellChangeTimes->{{3.6687760764630947`*^9, 3.6687760815947456`*^9}, 
   3.672629716308138*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "/.", "chevalier\[LetterSpace]clegg\[LetterSpace]prefactors"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Gamma]", "\[Rule]", 
    RowBox[{"5", "/", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"\[Eta]", "\[Rule]", 
    RowBox[{"5", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/", 
   SuperscriptBox["r", 
    RowBox[{"3", "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"secular\[LetterSpace]density", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6687760864353895`*^9, 3.66877613848425*^9}, {
  3.6726349068974657`*^9, 3.6726349152990556`*^9}}],

Cell[BoxData[{
 RowBox[{"mass\[LetterSpace]conservation", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", " ", "secular\[LetterSpace]density"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", 
    RowBox[{"5", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{"u", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "r", "]"}], "/.", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"u", "[", "r", "]"}], ",", "r"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     SqrtBox["GM"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"secular\[LetterSpace]velocity", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6687762415537148`*^9, 3.668776318728792*^9}, {
   3.668776592672*^9, 3.6687766480081854`*^9}, 3.6726349209150953`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"secular\[LetterSpace]velocity", "\[Equal]", "0"}], ",", "r"}], 
     "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"secular\[LetterSpace]stagnation", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6687762124576144`*^9, 3.668776217906099*^9}, {
   3.6687766300273924`*^9, 3.668776665176076*^9}, 3.6728338745056953`*^9}],

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", "secular\[LetterSpace]velocity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", 
    SqrtBox["c2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"rs", "\[Rule]", " ", "secular\[LetterSpace]stagnation"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "c2"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", 
    RowBox[{"5", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Gamma]", "\[Rule]", 
    RowBox[{"5", "/", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ExpandAll", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"secular\[LetterSpace]c2", "=", "%"}], ";"}]}], "Input",
 CellChangeTimes->{{3.668776680230121*^9, 3.6687767990321684`*^9}, 
   3.672634930373416*^9}],

Cell["Validation", "Text",
 CellChangeTimes->{{3.6687768161366315`*^9, 3.6687768248849125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "mass\[LetterSpace]conservation", ",", 
    "momentum\[LetterSpace]conservation", ",", 
    "energy\[LetterSpace]conservation"}], "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", "secular\[LetterSpace]velocity"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Rho]", "\[Rule]", "secular\[LetterSpace]density"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", 
    SqrtBox["secular\[LetterSpace]c2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", 
    RowBox[{"5", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Gamma]", "\[Rule]", 
    RowBox[{"5", "/", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"DD", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.668776827091777*^9, 3.6687769809280033`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.668776839149845*^9, 3.6687768740185957`*^9}, {
   3.6687769045959697`*^9, 3.6687769813029823`*^9}, 3.6687985503793945`*^9, 
   3.6688255564751153`*^9, 3.6688577256624136`*^9, 3.6688579635825205`*^9, 
   3.6688619432800975`*^9, 3.6695557611939726`*^9, 3.6695788073020744`*^9, 
   3.671415388183694*^9, 3.672141114888507*^9, 3.6726349331431503`*^9, 
   3.6728338818036633`*^9, 3.6731704327874393`*^9, 3.6734856365304623`*^9, {
   3.673485684199624*^9, 3.6734857072257013`*^9}, 3.673485772459137*^9, 
   3.6809695441866693`*^9, 3.729253716270356*^9}]
}, Open  ]],

Cell["Approximate solutions", "Chapter",
 CellChangeTimes->{{3.6732362128471546`*^9, 3.673236218884203*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"temp", ",", 
     RowBox[{"\[Eta]val", "=", 
      RowBox[{"5", "/", "2"}]}], ",", 
     RowBox[{"\[Gamma]val", "=", 
      RowBox[{"4", "/", "3"}]}], ",", "\[IndentingNewLine]", 
     "\[Rho]\[LetterSpace]inner", ",", "c2\[LetterSpace]inner", ",", 
     "u\[LetterSpace]inner", ",", "\[IndentingNewLine]", 
     "\[Rho]\[LetterSpace]mid", ",", "c2\[LetterSpace]mid", ",", 
     "u\[LetterSpace]mid", ",", "\[IndentingNewLine]", 
     "\[Rho]\[LetterSpace]outer", ",", " ", "c2\[LetterSpace]outer", ",", 
     "u\[LetterSpace]outer", ",", "m\[LetterSpace]outer"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m\[LetterSpace]outer", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", "/", "c"}], ")"}], "/.", 
      RowBox[{"(", 
       RowBox[{
       "chevalier\[LetterSpace]clegg\[LetterSpace]prefactors", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
          RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}]}], "}"}]}], 
       ")"}]}]}], ";"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.673236229792285*^9, 3.673236819110939*^9}, {
   3.673236851870939*^9, 3.673236860859005*^9}, {3.6732369039387226`*^9, 
   3.6732371528329477`*^9}, {3.67323808893019*^9, 3.6732382973181*^9}, {
   3.673238375372363*^9, 3.673238752332551*^9}, {3.673238784827506*^9, 
   3.6732388361755557`*^9}, {3.6732395325645704`*^9, 3.673239546462026*^9}, {
   3.6732396553008285`*^9, 3.6732396937913895`*^9}, {3.6732397670694747`*^9, 
   3.673239872989408*^9}, {3.673239934209462*^9, 3.6732399482462406`*^9}, {
   3.6732400127826405`*^9, 3.6732400232284675`*^9}, {3.6732401872840643`*^9, 
   3.673240230087518*^9}, {3.6732402659746304`*^9, 3.6732403853313155`*^9}, {
   3.6732404503130255`*^9, 3.6732404646071224`*^9}, {3.6732407124503884`*^9, 
   3.673240713432336*^9}, {3.6732407686699734`*^9, 3.6732408209393377`*^9}, {
   3.6732408530904827`*^9, 3.6732408568684306`*^9}, 3.67324110031437*^9, {
   3.673241273977369*^9, 3.6732413887287307`*^9}, {3.673241431959421*^9, 
   3.6732415350408*^9}, {3.67324158851239*^9, 3.673241918881716*^9}, {
   3.673242047744458*^9, 3.673242118191248*^9}, {3.6732421937284613`*^9, 
   3.6732423391170464`*^9}, {3.673242439123667*^9, 3.6732424620070205`*^9}, {
   3.673244584495966*^9, 3.6732445867813044`*^9}, {3.67340351164994*^9, 
   3.6734035531370997`*^9}, {3.673403607585012*^9, 3.6734036575321026`*^9}, {
   3.6734839540749035`*^9, 3.6734839710340004`*^9}}],

Cell["Phase Diagram", "Chapter",
 CellChangeTimes->{{3.6809714314636297`*^9, 3.680971440576819*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RegionPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "<", "3"}], "&&", 
      RowBox[{"\[Eta]", "<", 
       FractionBox[
        RowBox[{
         RowBox[{"3", "\[Gamma]"}], "+", "1"}], 
        RowBox[{"\[Gamma]", "+", "1"}]]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Gamma]", ">", 
         RowBox[{"5", "/", "3"}]}], "&&", 
        RowBox[{"\[Eta]", "<", "3"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Gamma]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", "\[Eta]"}], ")"}]}], "+", 
           RowBox[{"2", " ", "\[Eta]"}]}], "<", 
          RowBox[{"1", "+", 
           RowBox[{
            SuperscriptBox["\[Gamma]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", "\[Eta]"}], ")"}]}]}]}], ")"}], "&&", 
        RowBox[{"\[Eta]", ">", "3"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"\[Eta]", "<", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]", ",", "1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Eta]", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Gamma]\>\"", ",", "\"\<\[Eta]\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6809715485994797`*^9, 3.680971601667419*^9}, {
   3.680971649757712*^9, 3.6809716803481817`*^9}, {3.680971730517256*^9, 
   3.680971771398134*^9}, {3.680972182731984*^9, 3.680972201916794*^9}, 
   3.680972253371367*^9, {3.681004249562336*^9, 3.6810043069157467`*^9}, {
   3.6810043621602383`*^9, 3.6810043873681803`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJzt2ntYjOn/B/CZqR10YDqQjVKLlWO0ckjbfa/IivqGFCKknELksEKbY445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   "], {{
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl3nYl1URhs9xX3DfEIxFkkUQVBBRCEFBNgGRCNlkETcSNFFKEUXELdME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         "]], PolygonBox[CompressedData["
1:eJwtk9lTiGEUh89JkWjMuKlGXWRLhpowVLKGULbQ2Jfc19+E4lY0FNWFdaaa
xpiYaspkC1HdRMnWc+b3XTxznvN953vf871Lfn1jbUOKmZVBKvyEXW42RLwF
u/FUGMGHoRJfCO/wUdjj+iZqo2YZeRZ044/hB1SQvyE2wz58hnjbNMYm8hK4
gb+EbDzH9e11SMf3wxP8PpzHz8ED/BnswFNgEB+AJfhBeI63m+baS/42mXMp
fghe4A/hMn7JVRvPzuJnXHM9hcX4AZfHnP9hLXkXsQV2uv4x/i16yCCvcvXW
BhfxCy6Pnpbji+C96Z/+wRryu8Q7kIuvgx78HuTh66EXbzWtbR18M63xSdc3
UfvF9G6OOG6q2Ui+wbWWfXDaNWZrUlODX4Mp/KPJ/xAnTc9Okf9Kxv4KBeS1
8NnUY6GrJt5Fj/Fuljhmqskk/0v8BJ1QT74KHiVzHMavwgT+Aa7gK1178930
7nfiUVNObvCa0A+leBm8wptgG74Vbpqebca3uM5WPNuOTye1McZR8tXQkfQY
vVW7eokej+PHXHsTe+6uHmLuONMLXGcwzl7cmTTXnYm7Emcuxj7iWtuYI/Y+
7lDcnTgDRXixa2/iDpzAV7jOVqzhPPJCgDI=
         "]]}]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl2d0lkUQhbMTLNhAsHcsKIigWACjKGL77fHYKx4b0oRABE0UFEKEIBEk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         "]], PolygonBox[CompressedData["
1:eJwtlOdvzlEUx597UqkQQqpqa40m/hRqFrFXjZSWoiTU3jVr1t41a6X2Hq+8
lngltthCCCEEn2/OefHJ+Z77/O6959xzzlNQUlE8zTKZTBFkwUScSnieMpkP
MBk9B16j87F9YRP8w6+BS+hSeJz8m1XolfAd/QN0eBW8RT+F/ujt0Aj24hdh
q82/rYJirUNTqMfvh90KBrXJzyqHJ8nPnICuMD/7HQxA74LGUIffG7sWfqGX
CPRi+Iz+AuvR6+A3+g8MQt+DHnAf/wZ2PnxEd8MuhAXx2yuYix4IDeg3MBU9
3lwrxpnoefA++ZsORh+GlvAAvxd2BXxDV8Jy9DL4mnxNe6fDs+RnNKBvmsfy
En+G+Rsod33TE73UPLdy6IPeYJ5bNZw0fxO9RRvsXVgEn/ALsRuhBv4mr/Fu
9DjoCE3guHnMirU19pj5nborN2IfZq6Vg3phuPm36onT5jVVLdtjh8ARyIGH
yWszFFpFjc6a11S1VAzbYIz53ixYDSMgD34mr+VI89xU0xPmPabeyovcRkHb
yLHe/I30NlrbDKOhHSTYAWOhA2TDGfMeVu9q7ZT5TGgWtGdNxKRY1HPnzHta
vdwJewdumfdOd+we8zfW26rnd8ad2dHDtZGzctXM7Id90AyawyE4CC2ip45C
GXSJNzwPF6Gz+YxuiRyVm0Xtb5vHoh64bN6j6s0C7DW4Ai/wu2IvRM8Uxpma
ldnwKPnMKLYS81wVo2bnqvlezdAk8x5W72rPLPR18/8a3VGHnmJ+d07kpv+g
/MhRs3YgctfM/QeWxJv/
         "]]}]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlve7z3UYxs85T9axzrF1FA4yyqaFQiUaVkMkSouElq723v9Ee++997gk
IWQl68imwiFJdd/X8/pe3x9e3t/35/Mez7jvz9Fx2pzxs8tKSkqqSktKQuMQ
/XOj6C7W6sX3Yr5Yx/iDWM+4QGwSi8RisVH8KBaKX8U89v8uVotfxAb2ed2f
Yg1ra9jns3aLVezZKpaKZWIb489iO+NysYNxhdgsfhJLxG/E5flO3q8Uuxh9
xxbW+o49xOK8XYwd7NvLM9egfuR8n9hPPs77L3JwPQ7wrIZ166jZQd47rr8Z
He9/5OP7alnrc/8hPtegNDIWx14WObpOETm6xv9SI59VN7K+zukQ9/isw5zn
dXW05g/6UC9yrXNrEBl3LbXZwv5Gkbk518aRo3NqEjk6p6aRo+9sHhmT82sY
WS/vr4h87/wqI0fHNUC/O0Te0yzymff31+/2kWe0jszfefcUbSLz6CXaRubd
W1RF5tQyspeuX4vIWDzvK46KzLWfOFqUi4GiY2R+x4vqyPwKuncvT9C8U2Su
3lOLFk7W72OIfbDoxp2DRNfIepwoOkfWYAg+c4yniB6ilThJdImszXHiWPKe
hz7X4JWasqLnNpYVvbWBWJfSa/dvEdqrwQ+b0V/B2wWvr+WOxbz3noL3fFbB
e56fG5mzc1uBVwpe3MG67fTffVyFZneRg3Vn/RU8uZP796Lb1eh6NzHtYY/j
3ce6DdS+llgPos+Cxw6S6yHmW9DdIWp2gP3rOWMfeR5m3TZi93yS8pwo+vBt
KEFPBU+W4ifr8Ygo+rMM75aiRedRD636PmuwPn6ti57345lyvjf10bPjbYQX
Cj5sFEUfNsY3zaLorcooeq4C3dZQpwPk1xzdFjzchNxaoNsSdNqCPFsxb8W8
DFrzbCj+tCdPo2b22+l4z347A+/Z2yMifW7/nxXpMftkOH5uJ86M/EbYnyPx
ajV1qaKeo/Ct/elvw5H0YjQ+tCfH4E97byw+tPfG4UP77Rx8aD+fjW+70Js2
nFmX/OrQv3bE0oBc61OLHtSqnLz9fljkN6uKnnWkj02JvQlU874hdSqnl51Z
W0lcFezvwNpmxF5J/7ryrC19cczni/OYtyZvx3sqdXOeF4oLiPUiMYF+tKR+
LaAb91Sx1rWxn8rJtx376lGbPtSnG31pTn+n0ePu9MhnWy8Xs89amsR+r70s
ipoYQA0uFVMj9TRFXBLFb3xf4rlOzOHu9rwvp379qaG1Opk9/TinoNspPHMc
E8nP9TuFGvaktq6hv+Hjed+LeroPQ+mB194grifn28R8an1T5P/HrNGbxVzu
GEGe/WEqeQynT71hAj0ZRi99fw/Ocw9vFwvI4QpxeaSvrhJXRnppFHP/9vd+
VqS27NGrI/U6jvgcm/07nff20bWRXhpDnoM5y+dXs2cucY2mN4PAPerKHtfH
ehlLXZyDfTkj0g/+ezSbGH3fzEhv2L/XRNHDHiuIayZrOxFTE+7zGQUP+X0l
Z8xgfzV1aszdztV+tAatSevoVjGPfo+kvt5zi/guUh8DqXlHYp/F3dOprc+1
xqwv++VOsThSiy+JFyN1+pj4NlJnT4jHI338lHgyUmvPiKcjtfCo2ErdXxOv
RmrqFfFypMbfEK9H+vIOsTDShw+JjfTmEbE5UqPPiWcjNXiPWE5u94qV9Ps+
sZrcXhDPR3r6brGM2j0o1lOLu8SSSH3fL9bQg4fFpkhNTCYu+/QBsZa+vife
jdTjW+JN+vCN+DpSsx+I9yM18on4OFJHH4kPI/X7jng70gefiU8jdfqF+DxS
11+JLyO1+T+9c4v/
         "]], PolygonBox[CompressedData["
1:eJwt03lXz0EUx/HvaTwISVS/lOI5JDuVUpZsIWQvW0L2XVT2naxZi2zJli1k
iaxlyU6ehfc98/njdc6c79yZuTP3e6NzCzLzw4IgSEUHPHFBUIpwDEcDDqMH
MvEMSzAS2TiKxxiGXtiMEsX2xHE0YgSScVJ72NremlussyxmC44gCR2xB9cw
GLEowwntFYH9uIU0xOMQ7iMDiTiIu0hHAipQhE464wDuYAi645FysLOzdLdF
Gtsd9+I6UtAN23AWfdEFW3EafRCJXbiEgYjBblzBIISwA9XojyjsxEUMQDS2
4zz6oatq8RBDVZNyVOotO6t2x1QLq+E+3EAq4vBKOVuu4/BUbxqhmr5VTpbL
RLRiFaYgDzX4gMm603vlbLlO0txKjS3msvbI052v4hOmqaYX8A65unOL3ixG
Z1rsakzVGotdodxsTTOW6S45eK03s7caj3OKydEbVuENJujNz+AlxqqGNl6K
MfrWpJpG6putXa69bY9TeIHRqvlH1TiknL9gDaZjBurxG/Oc/yefq4ZWu1Fo
c/4fs39rJr5jHWYjH3X4ilmq6U3F2Jz1wGfneyZWZ1puxdrbcvzm/D8Rpz1r
laPllqK91+psO+Mn1qMAc3APf7HA+R7743yPWW/N19xGjS3ml/M9Zr01V3ff
oLG9wW2dYXtbD/7DJhRiIX443+PxyqHd+R5PVMwDrbFY64n/eXubyg==
         
         "]]}]}, {}, {}, {}, {}, {}, {}}, {
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt0tdSE2EAhuGENFJIQgqiItLURGyADUhAsYAiSLBiQ2M4hVO4B7wCT7wD
Zzz3niwUFUSfjB488/7z7c7O7sz21tcWV4OBQOA9LTTPRcpUqbHCBu/4xBdO
uPFAj+h9Fkhzkj/2o1rjh/OinqJEFw/4aX+oZU5zjEf8sj/WQ2R4QpbDdPLV
9TN6lkHOc45v9iEd5gIXGeG7/bJe4RKjXGXLPh7898FjBKmwbZrQFqqEmGTH
fl3DXCPCFLv2mxrlBjFyNGjnFq1085Ql8twmznGe8ZwC0yTo4QUvKTJDkl5e
sUwHd0jRx2v2vM8bvcss/dTZt7/Ve8wxwDy/7W36WT/ygU3WabBAhRIF8uRo
J0uGdPMZpEiSIE4rMaJECBP6/5/9BSCULcs=
       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0ltTzAEABfB/fZO89kmIShEJZWl3ayndlaKrdd1CWy4JXUQXdMFWLNlq
H5ppxoz0dfqZHn5z5ryeOXmh+pK6nCAIxsnPDYJq5YiM8Y6zdNNDL0eZoZw+
+hngGO85xx3i3KWAD1Rwj/s84DiznOchj0hwgjkuMMgQjylknos84SnDFLFA
JUlGGKWYj1TxjOe84CSfuMRLxnhFCZ8JMc5r3lBKO5e5xjZX6aCODPVcoYEs
17lJI5s0/d+VdZpJscYqnXznB0uEWSRCC785RRe3aCXNL35ymw1W+MIyUb7S
xhY3qOEtE0xymm/UMsU0Zyhjzwf+sc9f/rDLDlkypEmxyCyTjJEkQZxu2mkk
Ri01RIkQzjn83AH/Ylip
       "]]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwl0kVWlQEAgNEfnnvgHGbMWQ1LcAEwREqlJSRFJRSUEDAI6VJSeDzqJV0G
OsIlcM9hcFfwfVkP83Jy04IgaGIrPQg2OeU/D0JBkEk+3fRQzwaP+ME73vOc
TQrYopc+GghTyDb9DNBIhCJ2+MAgTexSzB5DDNPMPiUc8JFPtBDlMTE+84VW
4jwhwQijvCDJU1KMMU4bh5RyxFcmeMkxZZwwyRSvOKWcM6aZ4TXnVHDBLHO0
c0klV8yzQAfXVPGTRZbo5BfV/OYb3+niD8+4YZkV3vCXGv6xyhpvWaeWOrLJ
IMStxiccc8QhKZIkiBMjygH77LHLDhG2Caffv3MH0dZnMg==
       "]]}}}],
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 16},
  Frame->True,
  FrameLabel->{
    FormBox["\"\[Gamma]\"", TraditionalForm], 
    FormBox["\"\[Eta]\"", TraditionalForm]},
  Method->{"TransparentPolygonMesh" -> True, "AxesInFront" -> True},
  PlotRange->{{1, 2}, {0, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.680971568651597*^9, 3.680971602032473*^9, {3.680971662180311*^9, 
   3.6809716808097277`*^9}, {3.680971732683848*^9, 3.680971751112608*^9}, {
   3.680972188890806*^9, 3.680972203416625*^9}, 3.680972253690394*^9, {
   3.6810042610428877`*^9, 3.681004307703939*^9}, {3.681004364770865*^9, 
   3.6810043878012114`*^9}, 
   3.72925371644494*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Mach number equation", "Chapter",
 CellChangeTimes->{{3.6687942130583754`*^9, 3.6687942190944376`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "mass\[LetterSpace]conservation", ",", 
    "momentum\[LetterSpace]conservation", ",", 
    "energy\[LetterSpace]conservation"}], "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"q", "\[Rule]", " ", "mass\[LetterSpace]source"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{"m", " ", 
     SqrtBox[
      RowBox[{"\[Gamma]", " ", 
       RowBox[{"p", "/", "\[Rho]"}]}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Dt", "[", 
    RowBox[{"m", ",", "r"}], "]"}], "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dt", "[", 
         RowBox[{"m", ",", "r"}], "]"}], ",", 
        RowBox[{"Dt", "[", 
         RowBox[{"\[Rho]", ",", "r"}], "]"}], ",", 
        RowBox[{"Dt", "[", 
         RowBox[{"p", ",", "r"}], "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Dt", "[", 
     RowBox[{"\[Gamma]", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"p", "\[Rule]", " ", 
    RowBox[{"\[Rho]", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], "/", "\[Gamma]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Simplify", "@", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "integral\[LetterSpace]mass\[LetterSpace]conservation", ",", 
          "integral\[LetterSpace]energy\[LetterSpace]conservation"}], "}"}], "/.", 
        RowBox[{"u", "\[Rule]", " ", 
         RowBox[{"m", " ", "c"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Rho]", ",", "c"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", 
   RowBox[{"Dt", "[", 
    RowBox[{"r", ",", "\[Xi]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"bondi\[LetterSpace]radius", "*", "\[Xi]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"rs", "\[Rule]", " ", 
    RowBox[{"bondi\[LetterSpace]radius", "*", "\[Xi]s"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"GM", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Dt", "[", 
       RowBox[{"vw", ",", "_"}], "]"}], "\[RuleDelayed]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mach\[LetterSpace]number\[LetterSpace]derivative", "=", "%"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.669563974924816*^9, 3.6695641017487993`*^9}, {
  3.6695777013761253`*^9, 3.669577709016383*^9}, {3.669577979294075*^9, 
  3.6695779804397373`*^9}, {3.669578151636546*^9, 3.669578153465677*^9}, {
  3.669578450188557*^9, 3.669578455708538*^9}, {3.6695786141607924`*^9, 
  3.6695787149692097`*^9}, {3.669578750334312*^9, 3.6695787974940357`*^9}, {
  3.672702702018228*^9, 3.6727027128647556`*^9}}],

Cell[CellGroupData[{

Cell["Numerical integration", "Title",
 CellChangeTimes->{{3.729266693969013*^9, 3.729266727401614*^9}}],

Cell["Outer subsonic case", "Subtitle",
 CellChangeTimes->{{3.729271845213839*^9, 3.729271853333315*^9}}],

Cell["Find the inner sonic point", "Text",
 CellChangeTimes->{{3.7292684762996063`*^9, 3.729268486984727*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "calc\[LetterSpace]inner\[LetterSpace]sonic\[LetterSpace]point", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "temp", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
     "temp", " ", "=", " ", 
      "mach\[LetterSpace]number\[LetterSpace]derivative"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"Numerator", "[", "temp", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"\[Xi]s", "\[Rule]", "\[Xi]sguess"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "1"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      FractionBox["temp", 
       RowBox[{
        SuperscriptBox["\[Xi]", "3"], 
        RowBox[{"(", 
         RowBox[{"\[Xi]", "-", "\[Xi]sguess"}], ")"}]}]]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"Simplify", "[", "temp", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]", "/.", 
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{"temp", "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Xi]", ",", 
          RowBox[{"\[Xi]sguess", "/", "2"}]}], "}"}]}], "]"}]}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"calc\[LetterSpace]inner\[LetterSpace]sonic\[LetterSpace]point", "[", 
  RowBox[{
   RowBox[{"4", "/", "3"}], ",", "1.9", ",", "6.1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.729267763725719*^9, 3.729268011034583*^9}, {
   3.729268042507029*^9, 3.729268465345922*^9}, {3.729268841674275*^9, 
   3.729268849930931*^9}, {3.729517131249971*^9, 3.729517140128669*^9}, 
   3.729528538242731*^9}],

Cell[BoxData["1.6141579928780867`"], "Output",
 CellChangeTimes->{{3.729268199762185*^9, 3.729268350392454*^9}, {
   3.729268387416933*^9, 3.7292683976709347`*^9}, {3.729268450941101*^9, 
   3.72926846566434*^9}, {3.7292688435097523`*^9, 3.729268857176013*^9}, {
   3.729517136244134*^9, 3.7295171403241243`*^9}, 3.729528539173265*^9}]
}, Open  ]],

Cell["\<\
We are concerned with the outer subsonic case, so no exterior sonic point\
\>", "Text",
 CellChangeTimes->{{3.729268603727874*^9, 3.729268624520939*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
   "calc\[LetterSpace]mach\[LetterSpace]number\[LetterSpace]at\[LetterSpace]\
infinity", "[", 
    RowBox[{"\[Gamma]val_", ",", "\[Eta]val_"}], "]"}], ":=", 
   SqrtBox[
    FractionBox[
     RowBox[{"\[Eta]val", "-", "1"}], 
     RowBox[{"\[Gamma]val", 
      RowBox[{"(", 
       RowBox[{"3", "-", "\[Eta]val"}], ")"}]}]]]}], ";"}]], "Input",
 CellChangeTimes->{{3.729268548723403*^9, 3.729268597532728*^9}}],

Cell["Shooting functions inside out", "Text",
 CellChangeTimes->{{3.729268653444336*^9, 3.729268658352599*^9}, {
  3.729269091215892*^9, 3.7292690933190327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "temp", ",", "\[Xi]si", ",", "\[Xi]start", ",", "\[Xi]end", ",", "ode", 
      ",", "mstart"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Xi]si", "=", 
      RowBox[{
      "calc\[LetterSpace]inner\[LetterSpace]sonic\[LetterSpace]point", "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val", ",", "\[Xi]sguess"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]start", " ", "=", " ", 
      RowBox[{"\[Xi]si", "+", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], "*", 
        RowBox[{"(", 
         RowBox[{"\[Xi]sguess", "-", "\[Xi]si"}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mstart", "=", 
      RowBox[{"-", "0.999"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]end", " ", "=", " ", 
      RowBox[{"\[Xi]sguess", " ", "-", " ", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], 
        RowBox[{"(", 
         RowBox[{"\[Xi]sguess", "-", "\[Xi]si"}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ode", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"m", "'"}], "[", "\[Xi]", "]"}], "\[Equal]", 
        RowBox[{"(", 
         RowBox[{
         "mach\[LetterSpace]number\[LetterSpace]derivative", " ", "/.", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
            RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
            RowBox[{"\[Xi]s", "\[Rule]", "\[Xi]sguess"}], ",", 
            RowBox[{"m", "\[Rule]", 
             RowBox[{"m", "[", "\[Xi]", "]"}]}]}], "}"}]}], ")"}]}], ")"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "\[Xi]", "]"}], "/.", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ode", ",", 
           RowBox[{
            RowBox[{"m", "[", "\[Xi]start", "]"}], "\[Equal]", "mstart"}]}], 
          "}"}], ",", 
         RowBox[{"m", "[", "\[Xi]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Xi]start", ",", "\[Xi]end"}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], ",", "1.9", ",", "6.1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729268631241829*^9, 3.7292688299524593`*^9}, {
   3.729268870136703*^9, 3.729269084845913*^9}, 3.7292691920691643`*^9, {
   3.729528552495595*^9, 3.729528558698392*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj3k4lAkcgDXIOWuM64upKDyJiKbSOr4f2QjtKomKMDkickVJax1d+7Su
ZFPJVZSoGLJR64fRyrFUBpOU+0oZlGPGte0f7/M+75+vBivogDdFRETE8Tv/
2705RG9uSEDSfCpjW+b4WKvp++nPcQF5LaJapGicj5q/uj7YMSUgtfeOL3kP
8PFS+36fjlkBqTNrKaR283F0i7VmxKKAvJ+qK1zXzkfbS6b9ShQhOee8X9qv
hY9FHw2zn0oIyS8DhuId9XwMTmIwZuhC0vHajdyJSj6+HZHvuk4IyaSowq1J
ZXxkgkQ6c52Q3NNm8MOux3ycn5xSOK0jJBN2jpXl5PAx5kC9zFdSSM7ms42L
rvAxm8cYn7gpJBPL3FZFavOxd7C+YHjfApl3MF3byncCzTNfchjcRdLvfMFQ
U/dnZBYXUM/AMjm2ZqFgLG4cDa6UFRbmrZCMqIcEx/ITxsdsC0u9LgKzzQOa
pcJRNBn7bdPxvauAu/uX5hneCLI2qOsdolIgmHTj2jwZxqtVbYfL/6XAqd4X
Jtq3hlDk8rmsTbGi0PC+x1jy3iAOrg/fVrVbDN5GTMrfzhtAxSFWj7dADPYl
k3dGavtxD9Xr6blCcfgY0B9An+jDYfGKd+yA1aC14Vj6NK0P2zavUl5SlwCJ
PyZ2Gtn1or76nWz/QQmo20B9t3bhI149a+/00z1JMMtsDOOd+YDMpQkNI2cp
qC4irocxutH+wJCp5RppuBfGeVhX0oXFbS1BXi3SINc701B68h3Ga8lOFVyT
AUyqsdBW4aFLl2uGq6MsqPbti5/ldmDk82x3DQkq5Cfaheax21Eq0DhEqpEK
KQ/PrA2N4+KQLeeWaMwPIDyRW/wmqA05Vz0n/I3kQO/R6tt8/7cod8cxeear
HFg84bU3urxBx0CG1t6DNCiZX6rs83iNzt+MdXTKaXBeP9az8VkLduu515LK
8kBcOshlNDTj5YVo354geQDxumymZBP6sV+V0t7Iw8ZGWVVngwYMWZGRbdKl
Ay8vNSEorh6FSy6C5xe+t1Fkhf7YS6wcbE0wH6KD9y5DuuquOsz2BH1bUgH6
WNOeWFyLVf90hY9kK8BCTiZZQK9BSu2pBuqiAvj8SGk0YyLWn5Jl+zspAvvG
kfr1Xi+QI8q1OFyuCGK+rinJ/hU4pJ/24TVNCSqPrmSdfFqOpGWMeleoEhRH
Z2ys4JWiqkT4/Jo2JaBNO0XYqZWgGut4d7+eMmR1GDX9ZfwIHfOifM0SlUHb
xFbLg38fS6ITltXHlGGbT7Wxwtq7mCxVsNnEUgUoNj2DNcIMzD8/sTScqwK9
OnKuGrqpOHBxywe1JRUYjeUrDQdeQP/Oc/cfL6uA/Ra7Q83rLuDkplchFiIE
5N71o1a2xuNiE2u1rygBPtvN3xcaxqMiPd2ALUUAqzWYOzoTi1aZlDgbZQIC
3OsCE1eiMb+8UzvcgIB5ldFsNaNw1JPUmpIwJEDXo9W9Ju00sg+HPr9lREDn
7hBOuCAMqxZlHaq3E3DEwDtIuiYUOy0tI2VMCZh8lqEy4BCMkq1FTTk2BAya
lx7LGvbBRHVhGtOWgDI6y/7vJ96oGGrtUW9HgBg7wWT+rBeqK/V/+/wzAXbd
N2VfyrDQ+KjKOmMnAkZ4KfNh3kewqshrtPEQARXatpPRAme0Wi5hu7kQ0POl
JYeT4IQOOfbW8UcJuEivpQnLHbBj+qa8shsBoTpR0Z037NHVauT9g2ME6Pw+
LKVfa439acx8Ew8CdpgxSuY+W6LfSGxwi+f3n8spjSe2muJ/bCCa1A==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{2., 0},
  Method->{},
  PlotRange->{{1.6186438348852086`, 6.095514157992878}, {-0.998999837279543, 
   0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.7292687911619453`*^9, 3.729268945962008*^9}, {
   3.729269002013406*^9, 3.729269014551798*^9}, {3.729269053322319*^9, 
   3.729269085058756*^9}, 3.729269192392498*^9, {3.7295285538874197`*^9, 
   3.729528559569152*^9}}]
}, Open  ]],

Cell["Shooting functions outside in", "Text",
 CellChangeTimes->{{3.729268653444336*^9, 3.729268658352599*^9}, {
  3.729269091215892*^9, 3.729269101584815*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]subsonic", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Xi]start", ",", "\[Xi]end", ",", "mend", ",", "ode"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Xi]end", " ", "=", " ", 
      RowBox[{"100", "*", "\[Xi]sguess"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mend", "=", 
      RowBox[{
      "calc\[LetterSpace]mach\[LetterSpace]number\[LetterSpace]at\
\[LetterSpace]infinity", "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Xi]start", " ", "=", " ", 
      RowBox[{"\[Xi]sguess", "*", "1.01"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ode", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"m", "'"}], "[", "\[Xi]", "]"}], "\[Equal]", 
        RowBox[{"(", 
         RowBox[{
         "mach\[LetterSpace]number\[LetterSpace]derivative", " ", "/.", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
            RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
            RowBox[{"\[Xi]s", "\[Rule]", "\[Xi]sguess"}], ",", 
            RowBox[{"m", "\[Rule]", 
             RowBox[{"m", "[", "\[Xi]", "]"}]}]}], "}"}]}], ")"}]}], ")"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "\[Xi]", "]"}], "/.", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ode", ",", 
           RowBox[{
            RowBox[{"m", "[", "\[Xi]end", "]"}], "\[Equal]", "mend"}]}], 
          "}"}], ",", 
         RowBox[{"m", "[", "\[Xi]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Xi]start", ",", "\[Xi]end"}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]subsonic", "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], ",", "1.9", ",", "6.1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729269108273782*^9, 3.729269287380989*^9}, {
  3.72952857828605*^9, 3.729528582795879*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0Xk41QkXB3Aksjeyq3ldVIrUNLIknZPdtWS/uZI1RbK7KVvuLfugbGmQ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.635},
  Method->{},
  PlotRange->{{6.161, 610.}, {0.6374529509540284, 0.7833494502395955}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.7292692781615143`*^9, 3.7292692877852287`*^9}, 
   3.729528583510816*^9}]
}, Open  ]],

Cell["Find stagnation point ", "Text",
 CellChangeTimes->{{3.729269298449568*^9, 3.729269310247602*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"slope\[LetterSpace]difference\[LetterSpace]subsonic", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"inside\[LetterSpace]leg", ",", "outside\[LetterSpace]leg"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Assert", "[", 
      RowBox[{"NumericQ", "[", "\[Gamma]val", "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Assert", "[", 
      RowBox[{"NumericQ", "[", "\[Eta]val", "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Assert", "[", 
      RowBox[{"NumericQ", "[", "\[Xi]sguess", "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"inside\[LetterSpace]leg", "=", 
      RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val", ",", "\[Xi]sguess"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"outside\[LetterSpace]leg", "=", 
      RowBox[{
      "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]subsonic", "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val", ",", "\[Xi]sguess"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Xi]"], "inside\[LetterSpace]leg"}], 
         ")"}], "/.", 
        RowBox[{"\[Xi]", "\[Rule]", 
         RowBox[{"inside\[LetterSpace]leg", "[", 
          RowBox[{"[", 
           RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], 
       ")"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Xi]"], "outside\[LetterSpace]leg"}], 
         ")"}], "/.", 
        RowBox[{"\[Xi]", "\[Rule]", 
         RowBox[{"outside\[LetterSpace]leg", "[", 
          RowBox[{"[", 
           RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"slope\[LetterSpace]difference\[LetterSpace]subsonic", "[", 
  RowBox[{
   RowBox[{"4", "/", "3"}], ",", "1.9", ",", "6.1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.729269349706682*^9, 3.729269520118382*^9}, {
  3.729270312897155*^9, 3.729270343417672*^9}, {3.7295286703784*^9, 
  3.729528674273384*^9}}],

Cell[BoxData["0.007308116652197091`"], "Output",
 CellChangeTimes->{{3.7292694744678183`*^9, 3.729269520413288*^9}, 
   3.729270343895372*^9, 3.729528675048073*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wrapper", "[", "x_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"slope\[LetterSpace]difference\[LetterSpace]subsonic", "[", 
     RowBox[{
      RowBox[{"4", "/", "3"}], ",", "1.9", ",", "x"}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"wrapper", "[", "x", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "3", ",", "10", ",", "0.2"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Joined", "->", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.72926999729106*^9, 3.7292700136983433`*^9}, {
  3.729270069987492*^9, 3.72927007014642*^9}, {3.729270350938135*^9, 
  3.729270518254043*^9}, {3.72927058689221*^9, 3.7292705921654043`*^9}, {
  3.729270788082629*^9, 3.729270815101166*^9}, {3.7292709673723803`*^9, 
  3.729270967523964*^9}, {3.729528686213605*^9, 3.729528693645157*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEcDqzKXQdO5N2znzUTBDgdtjZOCprle9PeGAy4
HRT3HecVkbhqf/YMCPA48DLe8p00+6J9GhjwOcg+OqRcmXLWHmKegMOpVZ8v
zaw7AVUv4MCxbpaRRuQRqPmCDjf+Oa2ouXgAql/Iwa9JmT1/xm6ofcIOWUnN
oszp26DmiThUMv+U63i9EWqeiMMLk5cRN4XWQM0TdTimECaxKmgp1DwxB4vD
eUdZH8yzNwGbJ+6wokS4483UKVDzJBw8ni+MXKLcDjVPwuHBrgNvyy1yoeZJ
Ohy4c4phW33Wfoh5Ug4b9l37afmsaT/EPGkHA2ap9p+7evdDzJNxUFmz7pDd
ssn7IebJOBxhCE0xfTh9P8Q8WQeGlCl/S+fP3p8ONk/O4Uz360sH38+Dmifv
kO09/0f++wVQ8xQcFpzQePzJehHUfgWHTa9OxHklLYaar+CQHnF0xtK0JVD9
ig6zWvt2H/JZCrVP0eH42lTFu+LLoOYpOeyKe8l/69QyqHlKDjrCJaqOGcuh
5ik5SEzO9PH4tBxqnrLDrKapiV+zVkDNU3YIa4yQY7uyAmqeisOVgyvm8eiv
3A8A75L5fg==
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3., 0.},
  Method->{},
  PlotRange->{{3., 10.}, {-0.049187082641200114`, 0.47551173021979337`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.14, 0.14}, {0.01049397625721987, 
   0.01049397625721987}}]], "Output",
 CellChangeTimes->{{3.7292700016390676`*^9, 3.7292700155404873`*^9}, 
   3.7292700708418713`*^9, {3.7292703512768106`*^9, 3.729270517337516*^9}, {
   3.729270590729743*^9, 3.729270594092061*^9}, {3.729270803986112*^9, 
   3.7292708175437326`*^9}, 3.729270969591961*^9, 3.729272502989443*^9, 
   3.7295286946289062`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "find\[LetterSpace]stagnation\[LetterSpace]point\[LetterSpace]bisection", 
   "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "ileft_", ",", "iright_"}],
    "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "left", ",", "right", ",", "vl", ",", "vr", ",", "i", ",", "middle", ",",
       "vm"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"left", "=", "ileft"}], ";", "\[IndentingNewLine]", 
     RowBox[{"right", "=", "iright"}], ";", "\[IndentingNewLine]", 
     RowBox[{"vl", "=", 
      RowBox[{"wrapper", "[", "left", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vr", "=", 
      RowBox[{"wrapper", "[", "right", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Assert", "[", 
      RowBox[{
       RowBox[{"vl", "*", "vr"}], "<", "0"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<", "10"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"middle", "=", 
         RowBox[{"0.5", "*", 
          RowBox[{"(", 
           RowBox[{"left", "+", "right"}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"vm", "=", 
         RowBox[{"wrapper", "[", "middle", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"vm", "<", "0"}], ",", 
          RowBox[{"right", "=", "middle"}], ",", 
          RowBox[{"left", "=", "middle"}]}], "]"}]}]}], "\[IndentingNewLine]",
       "]"}], ";", "\[IndentingNewLine]", "middle"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"my\[LetterSpace]\[Xi]st", "=", 
  RowBox[{
  "find\[LetterSpace]stagnation\[LetterSpace]point\[LetterSpace]bisection", 
   "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], ",", "1.9", ",", "3", ",", "10"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.729270983986045*^9, 3.72927118034558*^9}, {
  3.729271219550305*^9, 3.729271276608301*^9}, {3.7292724754954367`*^9, 
  3.729272494422764*^9}, {3.729528736082076*^9, 3.729528745273439*^9}, {
  3.729528938529427*^9, 3.7295289404410877`*^9}}],

Cell[BoxData["6.294921875`"], "Output",
 CellChangeTimes->{{3.729271081662608*^9, 3.72927109168434*^9}, {
   3.729271155999054*^9, 3.729271180950186*^9}, {3.729271273114214*^9, 
   3.729271277127405*^9}, {3.7292724948892107`*^9, 3.7292725033717823`*^9}, 
   3.7295287459890413`*^9, 3.729528941105302*^9}]
}, Open  ]],

Cell["now we can get the profiles", "Text",
 CellChangeTimes->{{3.7295288775598583`*^9, 3.7295288918245583`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{
   "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]subsonic", "[", 
    RowBox[{
     RowBox[{"4", "/", "3"}], ",", "1.9", ",", "my\[LetterSpace]\[Xi]st"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_beyond_stagnation.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729517811276717*^9, 3.729517811696678*^9}, {
  3.729517886524498*^9, 3.729517918613329*^9}, {3.7295179662526217`*^9, 
  3.72951808497908*^9}, {3.729518295808043*^9, 3.729518360434783*^9}, {
  3.729518444816001*^9, 3.729518476134206*^9}, {3.7295185201899023`*^9, 
  3.729518520309836*^9}, {3.729528925471878*^9, 3.729528943735161*^9}, {
  3.72952898750424*^9, 3.7295289933036213`*^9}}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_beyond_stagnation.csv\"\>"], \
"Output",
 CellChangeTimes->{
  3.72951831021206*^9, 3.72951836253561*^9, 3.72951847687197*^9, 
   3.72951852107654*^9, {3.729528977290586*^9, 3.729528993984082*^9}, 
   3.729529126226343*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
    RowBox[{
     RowBox[{"4", "/", "3"}], ",", "1.9", ",", "my\[LetterSpace]\[Xi]st"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_inner_sonic2stagnation.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729517811276717*^9, 3.729517811696678*^9}, {
  3.729517886524498*^9, 3.729517918613329*^9}, {3.7295179662526217`*^9, 
  3.72951808497908*^9}, {3.729518295808043*^9, 3.729518360434783*^9}, {
  3.729518444816001*^9, 3.729518476134206*^9}, {3.7295185201899023`*^9, 
  3.729518520309836*^9}, {3.729528925471878*^9, 3.729528943735161*^9}, {
  3.72952898750424*^9, 3.7295290403439817`*^9}}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_inner_sonic2stagnation.csv\"\>"]\
, "Output",
 CellChangeTimes->{3.7295290528303843`*^9, 3.72952912751341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"temp", ",", "ode", ",", 
      RowBox[{"\[Gamma]val", "=", 
       RowBox[{"4", "/", "3"}]}], ",", 
      RowBox[{"\[Eta]val", "=", "1.9"}], ",", "\[Xi]si", ",", "\[Xi]start", 
      ",", "\[Xi]end"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Xi]si", "=", 
      RowBox[{
      "calc\[LetterSpace]inner\[LetterSpace]sonic\[LetterSpace]point", "[", 
       RowBox[{
       "\[Gamma]val", ",", "\[Eta]val", ",", "my\[LetterSpace]\[Xi]st"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
     "temp", "=", "mach\[LetterSpace]number\[LetterSpace]derivative"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
         RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
         RowBox[{"\[Xi]s", "\[Rule]", " ", "my\[LetterSpace]\[Xi]st"}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ode", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "'"}], "[", "\[Xi]", "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"temp", "/.", 
         RowBox[{"m", "\[Rule]", " ", 
          RowBox[{"m", "[", "\[Xi]", "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Xi]start", "=", 
      RowBox[{"\[Xi]si", "/", "10"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]end", "=", 
      RowBox[{"\[Xi]si", "*", "0.99"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "\[Xi]", "]"}], "/.", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ode", ",", 
           RowBox[{
            RowBox[{"m", "[", "\[Xi]end", "]"}], "\[Equal]", 
            RowBox[{"-", "1.01"}]}]}], "}"}], ",", 
         RowBox[{"m", "[", "\[Xi]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Xi]start", ",", "\[Xi]end"}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_beyond_inner_sonic.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729518604446335*^9, 3.729518640459708*^9}, {
  3.729518694779271*^9, 3.729519035053505*^9}, {3.729519115076941*^9, 
  3.729519194996291*^9}, {3.729522622403668*^9, 3.729522628377308*^9}, {
  3.729529072143309*^9, 3.7295290722082644`*^9}}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_beyond_inner_sonic.csv\"\>"], \
"Output",
 CellChangeTimes->{3.729529078832274*^9, 3.72952912939159*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Outer supersonic case", "Subsubtitle",
 CellChangeTimes->{{3.7292718600179768`*^9, 3.729271865030552*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "calc\[LetterSpace]outer\[LetterSpace]sonic\[LetterSpace]point", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "temp", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"temp", "=", " ", 
      RowBox[{
       RowBox[{
       "Numerator", "[", "mach\[LetterSpace]number\[LetterSpace]derivative", 
        "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m", "\[Rule]", "1"}], ",", 
         RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
         RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
         RowBox[{"\[Xi]s", "\[Rule]", "\[Xi]sguess"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Xi]", "/.", 
      RowBox[{"FindRoot", "[", 
       RowBox[{"temp", ",", 
        RowBox[{"{", 
         RowBox[{"\[Xi]", ",", 
          RowBox[{"10", "*", "\[Xi]sguess"}]}], "}"}], ",", 
        RowBox[{"PrecisionGoal", "\[Rule]", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}], ",", 
        RowBox[{"AccuracyGoal", "\[Rule]", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"calc\[LetterSpace]outer\[LetterSpace]sonic\[LetterSpace]point", "[", 
  RowBox[{
   RowBox[{"4", "/", "3"}], ",", "2.9", ",", "6.1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.729271869835932*^9, 3.7292720042235193`*^9}, {
   3.729516468752561*^9, 3.7295164794390287`*^9}, {3.72951651537566*^9, 
   3.729516522727221*^9}, {3.729516595631537*^9, 3.729516598527194*^9}, 
   3.729516631487657*^9, {3.7295167014717283`*^9, 3.7295167023179493`*^9}, {
   3.729517077359309*^9, 3.72951707763091*^9}}],

Cell[BoxData["28.256074215629262`"], "Output",
 CellChangeTimes->{{3.729271914929343*^9, 3.729272004685267*^9}, 
   3.729516479738613*^9, {3.7295165183296623`*^9, 3.7295165231066008`*^9}, 
   3.729516598984869*^9, 3.7295166321853724`*^9, 3.729516703225566*^9, 
   3.7295167642144547`*^9, 3.729517154655099*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"calc\[LetterSpace]inner\[LetterSpace]sonic\[LetterSpace]point", "[", 
  RowBox[{
   RowBox[{"4", "/", "3"}], ",", "2.9", ",", "6.1"}], "]"}]], "Input",
 CellChangeTimes->{{3.729517068120493*^9, 3.729517083929789*^9}}],

Cell[BoxData["1.2701567844894612`"], "Output",
 CellChangeTimes->{3.7295170843480883`*^9, 3.729517157364357*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]supersonic", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "temp", ",", "\[Xi]so", ",", "\[Xi]start", ",", "\[Xi]end", ",", "mend", 
      ",", "ode"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Xi]so", "=", 
      RowBox[{
      "calc\[LetterSpace]outer\[LetterSpace]sonic\[LetterSpace]point", "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val", ",", "\[Xi]sguess"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]start", "=", 
      RowBox[{"\[Xi]sguess", "+", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], 
        RowBox[{"(", 
         RowBox[{"\[Xi]so", "-", "\[Xi]sguess"}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Xi]end", "=", 
      RowBox[{"\[Xi]so", "-", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], 
        RowBox[{"(", 
         RowBox[{"\[Xi]so", "-", "\[Xi]sguess"}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mend", "=", "0.999"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ode", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "'"}], "[", "\[Xi]", "]"}], "==", 
       RowBox[{"(", 
        RowBox[{"mach\[LetterSpace]number\[LetterSpace]derivative", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
           RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
           RowBox[{"\[Xi]s", "\[Rule]", "\[Xi]sguess"}], ",", 
           RowBox[{"m", "\[Rule]", 
            RowBox[{"m", "[", "\[Xi]", "]"}]}]}], "}"}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "\[Xi]", "]"}], "/.", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ode", ",", 
           RowBox[{
            RowBox[{"m", "[", "\[Xi]end", "]"}], "\[Equal]", "mend"}]}], 
          "}"}], ",", 
         RowBox[{"m", "[", "\[Xi]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Xi]start", ",", "\[Xi]end"}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]supersonic", "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], ",", "2.8", ",", "6.3"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729272012443429*^9, 3.729272035465366*^9}, {
   3.7292720692095327`*^9, 3.7292722922632427`*^9}, {3.729516486943038*^9, 
   3.729516568271099*^9}, 3.729516635303495*^9, {3.7295166742703867`*^9, 
   3.7295166743492737`*^9}, {3.729516779215399*^9, 3.729516780645214*^9}, {
   3.729516913000342*^9, 3.729516960427593*^9}, {3.7295171690222273`*^9, 
   3.7295171697242203`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj3k4FHgcxkUpFZJapjCVI+Q+x5HvV0LbRihRolVkJaI8iJzrka2MThlX
rmWZjRJb8VRSTEs5R27GNY4x88tRLHqs/nif9/k8z/u8z/vuPnvJyVtYSEjI
ZVU/vORiuU2KHQVnmU+KJ+SCwDdYrKfImYKdDzOZ4BgCStc8Lr1yp2A2gXeZ
sRHAuLkhdcSfgsofPRRseHEQX3x6Qo9OQWNq4oZZ1SQ4Nb72VlMjBYv0o1O/
56eCqJdzywaHHfhM6YtGuXgBnHH75hbhtBO5RZ4VvarlIE1lTHTHyeP9GpqJ
b28NTBa/H5ehU7HMue3oxeV/4WEs53EiaxdaU1wYJyjNYCqbnFfTtxtZ1oPn
oqhtQLYKO/kN7sEbH+OUJEvaQTnsT/OWRUX8Urm3ZdCwE+5a6Xpul1TGKlF2
i0FkN2y5EmvxYYsKeimd6ZoP7oUt4sKuNNW9+MJn57RwUD/s3mSrLqOpiga/
OsgNbeeA76VgI7aGGpo0We1qGeSAnkVrlP0BdVTLKg9eUzYI4kFz0cbW+9DS
ni+933cIfCVsX/W5a2CvWWWzmPIwLEvFGZwN0sQ0b2FmdNswZF+N9XK+rIVb
beWfqwWMQN0vT5vX/aGN2xbvJYyJj8JKdWv4XRsdDA6tJ5SMUTgt5c2MadPB
Z1Wb6NbaXGDf5y30ueuiXqm5puNLLjgfZufO9OtiwfXy9jqDMZAxbJ8cvaCH
mrMuJVAxBoOOtOTbfD3MMLvSFqk6DqycZIdif31UPM9inHowDnyVldLcBX1c
Gg6xU1o/AXL9zX5O4QZ4+2ThYKL/BNyqr6zliBpig0yISW7nBMhMppr33zZE
0Z7Fg7IWk8A065K8J2WEYYFrX+cyJiGmRjdWJdMI5xc9RSr/mwT3iCn7IKox
9nWkZKc58OCET7rJvkfGSPV5HHYwjwfJiWdr3qnR8FGo45qjizxo6blZKM2k
YeKOzj17f56C416f1A8Ym+DxPEcDzYwpGFAI2qhaaYKNyjI/xY9NQcJmsfWR
pqYom0SL9dfmg7/2y5wntaao9LQh5mQEH9zjG1LTbc3QKsdO0bWaD3SJb5re
bDM8JjmXoiEmgO6GbZxMD3M82fhGs9FeANpVDwRJA+botjScrkYXQO2AVvpp
v/1Iy0mo0W0RwDkj9fwh/n7caEK9bSNBQL6aUt/hb4H5bkr8xkMEZKJ305kL
Fih8Pe9IXwKBHYE3S4zCAU+dF0yEvCFwxChJ4eo1QN9Hgu7AagKRy3R6VRTg
8annzy68JcBJvBuAvwMeJp/kPN4RKMhhaB2+BQjuwZ+sWAT02wpL3LMA1el1
RRubCHgxihSyswEVubOyIs0EUs4w6UO5gAdsNwcurfIiryTApxDQct/3dl4r
geq1/2gFPQGsf9sZ3fD5x573JfE1gKJ3r1om9BOIWq5VYL0HlLLtUIscIFBa
w6KLsQDrpnUXrnAIbD3aEEBvADz4tsjGc4hAp0+rViob0EF6NMOUS2CjFjur
+zOgK+POXzpjBMzm2iXkuwB/k6PdVxknkBXTJcjpA0zseL0iNUnAm8EpYXIB
N7GaCrj8H/uHFATjgPnM12o9AgIflEfoOjzAb5vjDjURAhplYwEVZPVPblpL
xTQBj7CJ/vlpQPvltIbCGQLJFjx70zlAWprU+dRZAjP1Aq03C4Avyzg2l78S
ULrzJWvNEqDdsI2f6zcCzi4zEge/A1qYzL4znCeQID8XlbACeN1nJkVkgUDv
dHjoiBAiN9SOUrHKX9kRpeuEEQU6Nxz0/iMg8eLamIoIYuGKheWxVVZJj6Qe
Wov4N/NrJnc1D1FRLr7rENPZuf2Nq/3/A8H9pe4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{10., 0},
  Method->{},
  PlotRange->{{6.3257680458464876`, 32.04227780064101}, {0., 
   0.999185206826941}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.72927211169604*^9, {3.7292722122280293`*^9, 3.7292722927021847`*^9}, {
   3.729516494243874*^9, 3.729516568528201*^9}, 3.729516601814838*^9, 
   3.7295166358032084`*^9, 3.729516675120319*^9, 3.72951670604112*^9, {
   3.729516773522072*^9, 3.729516780935007*^9}, {3.7295169143212957`*^9, 
   3.729516960804059*^9}, {3.729517159026648*^9, 3.7295171703026953`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], ",", "2.9", ",", "6.3"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", 
       RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.72951680091614*^9, 3.729516808787231*^9}, {
  3.729516907484509*^9, 3.729516956195669*^9}, {3.729517163501018*^9, 
  3.729517164211721*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3k41AkYwHFnGfcQZmwlR1jUkpQsfi9CtHKukGXdUq5UQyqbrXF3iUeY
wePYlCNXbUqvHBlHs448QlpXiBjVzxV2t/3j+3yer7JvuFOAAB8fn/O3/ldQ
99ihzViSEFqpUeeu8FCy9PiCTTxJUJytK4Lf81BRxacwM5EkfBgG/ilDPFTP
CXGbuE4SGw6crJ09PNy37ayEbgZJLNUp19tweGiadqnpYg5JJJvEJTQjD223
JDDaC0jCLlu58tRjHvqu3h3zrSCJdrQIFv+Dh2GRhZmVtSQh2tmtsczm4YXZ
sqMb9SQh+2A1Yi6Th7ffYl1GG0m8KcvhX2TysKnxfRJnlCQ0LqUOmgXxMN7x
0lC65RLh5d1QMzC7gAJRZbFaUsvEd1lb/Vy+zmOQVFOsWcsKwVKaLpKV+Yga
iub+Pp5rhFrrp8rMsFm0Ss3pifv4lVhcCcwlPs1gx/GyjQT2BpGoOiGxP3Ia
S29pSN/V/4fQVxXPTVGdwgU1j7H02X8Jzl93q8R7J7FdqibnZRcf7BDhCrNy
J/DI4YX6tgx+KGd9cSxKG8cLu4WfNIQLgPop+1m7mDEcMnHUNvxRELg/qSw7
M0fxA0V0tEpACBz6KTtEbf/GB/HsqF3DQjDT4+FeETuC2fuCY2WLhYGvMIBt
PTGMxjckfNfjtoBmKIX/JTGEaXlKKeOuWyFT2rei/MkbFJ8O1DymJAJt7XpX
Z7wH0HQ4qahiVQSIpNKMg+v9yNoyfie9mQIFw4IHfJ+/xsp3cv6heaKQzClp
iGb0YUTIo3NWDDGw1Z2clbLqRe89qeuFIA5c7uafPxzoQX6Wya/LihKQaHjF
pmt7N3ZbqB16NSUBk20p1LcWXLRnM1wKKyQhr+PZ76unu/C34pJjYQlSkF7K
ZXpd7cDFyGvv3mlKg7wiydDr5mBM0G7hK5nSkHzUcnVcrA2HHq13qQhQgWRa
W0f4tWJvwUcuM5AK/KYjdVozzajqdxQC+qhQPW1uSfdqQrHGljnhQzJwo7fr
c8lmI3aeP2tYkisDlgPkw9d+iJOCt8lGEVkQXHAudqp6hnd0OmZZobJgQw3P
j7CuR5Z2hMPSkCysay6vSLc+RpOXuouSZtvAXD/388i1Oqyr19DTLN4G3hef
vREJrkHmtdSxp1Q5oLZRd6zpV+HCnFgXlSEHMp69PaxzFVipubZ7fFIO7Ie9
X6iduI9HcLtytYM8fDGYTuq+XILRnzxcD9fJQ4dLg+p9SiHyf92y7qCiAGrq
RNGjUTYqs18NKiUqgPY8U7s9NAvpuR3uC3MKMKLjuqva/TaGRBjYHHSjQdsJ
p9atlER0Gq0/Y95Ag/7ndooUnxgsUOnMF0YapDRPaT3djMZF/2Eup5EGBk01
tZezozHtw7qWfQsNjKsbNYxeM5Dz2XjiRCcNxFYHD8QfOY+mwuh8bpAGI2wH
N5f9Uail1bz/3hIN7Ju+uA/ohWDM6T7fUys00Guiql0PP4mciombe9dosDff
WjmoPBgD9IXmaze+fYYXK+77IMw3tix+IUgHoGms2Kj6o7x9m9wwlQ7Bbx/S
Lht5YsCtAQu2LB1kWs+k6NR7YG3fdKSPHB0sJxj3dhq5o6ObCHeaRofB7Pzq
V0aumOpjwySV6JCgmt30M+GAw4XutY+V6ZCoH3AV4u1Qa+rk+AVVOoRZee30
ZNoiJyTZlF+DDjPmKy3qNw+jQnn26RZNOsxX5RX2Z5hhIO9+doIWHdDllyty
hiZYq/eUY6tDhyjeHkqq5UEUPNu5LLGXDs1ZglWSLnr4H2aFl2I=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{2., 0},
  Method->{},
  PlotRange->{{1.280270687615467, 6.294975245933549}, {-0.9989996677320225, 
   0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.7295168092486973`*^9, {3.729516908643044*^9, 3.729516956529187*^9}, {
   3.729517160716241*^9, 3.729517165176449*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"slope\[LetterSpace]difference\[LetterSpace]supersonic", "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "\[Xi]sguess_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"inside\[LetterSpace]leg", ",", "outside\[LetterSpace]leg"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Assert", "[", 
      RowBox[{"NumericQ", "[", "\[Gamma]val", "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Assert", "[", 
      RowBox[{"NumericQ", "[", "\[Eta]val", "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Assert", "[", 
      RowBox[{"NumericQ", "[", "\[Xi]sguess", "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"inside\[LetterSpace]leg", "=", 
      RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val", ",", "\[Xi]sguess"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"outside\[LetterSpace]leg", "=", 
      RowBox[{
      "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]supersonic", 
       "[", 
       RowBox[{"\[Gamma]val", ",", "\[Eta]val", ",", "\[Xi]sguess"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Xi]"], "inside\[LetterSpace]leg"}], 
         ")"}], "/.", 
        RowBox[{"\[Xi]", "\[Rule]", 
         RowBox[{"inside\[LetterSpace]leg", "[", 
          RowBox[{"[", 
           RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], 
       ")"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Xi]"], "outside\[LetterSpace]leg"}], 
         ")"}], "/.", 
        RowBox[{"\[Xi]", "\[Rule]", 
         RowBox[{"outside\[LetterSpace]leg", "[", 
          RowBox[{"[", 
           RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"slope\[LetterSpace]difference\[LetterSpace]supersonic", "[", 
  RowBox[{
   RowBox[{"4", "/", "3"}], ",", "2.9", ",", "6.3"}], "]"}]}], "Input",
 CellChangeTimes->{{3.729269349706682*^9, 3.729269520118382*^9}, {
  3.729270312897155*^9, 3.729270343417672*^9}, {3.72927231399561*^9, 
  3.729272338688477*^9}, {3.729516658323127*^9, 3.729516662890142*^9}, {
  3.729516786099154*^9, 3.7295167866973457`*^9}, {3.729516971995193*^9, 
  3.72951697241643*^9}, {3.7295171754031687`*^9, 3.729517176073455*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.11671616462262582`"}]], "Output",
 CellChangeTimes->{3.729272339055106*^9, 3.7295167194111977`*^9, 
  3.7295167870197*^9, 3.729516972943099*^9, 3.729517176627099*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wrapper", "[", "x_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"slope\[LetterSpace]difference\[LetterSpace]supersonic", "[", 
     RowBox[{
      RowBox[{"4", "/", "3"}], ",", "2.9", ",", "x"}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"wrapper", "[", "x", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "4", ",", "8", ",", "0.1"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Joined", "->", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.72926999729106*^9, 3.7292700136983433`*^9}, {
  3.729270069987492*^9, 3.72927007014642*^9}, {3.729270350938135*^9, 
  3.729270518254043*^9}, {3.72927058689221*^9, 3.7292705921654043`*^9}, {
  3.729270788082629*^9, 3.729270815101166*^9}, {3.7292709673723803`*^9, 
  3.729270967523964*^9}, {3.72927235184341*^9, 3.729272416572125*^9}, {
  3.729272447484166*^9, 3.729272461826941*^9}, {3.729516980269401*^9, 
  3.7295170506444473`*^9}, {3.729517181541301*^9, 3.729517191157234*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.729517006120537*^9, 3.729517050893931*^9}, {
  3.729517184436328*^9, 3.729517191700974*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.729517006120537*^9, 3.729517050893931*^9}, {
  3.729517184436328*^9, 3.7295171917407618`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.729517006120537*^9, 3.729517050893931*^9}, {
  3.729517184436328*^9, 3.729517192257134*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(FindRoot \
:: lstol\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.729517006120537*^9, 3.729517050893931*^9}, {
  3.729517184436328*^9, 3.729517192315281*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJw1zF1IU3EcxvGTY0ov0M42d/bmtmBlWyrGZhcV+ATzSi9ijgY2FAwlyKjU
i+DUhZUvYFlkiFqI3ZQsVlKYU3f2P4mYpBYZqFBRhmAXOgwmQVratt++8PDc
fQ5UX/LWZHAc5/i/xKdSof/IyoU5ZWtxbTIVuJZG/7twJZudSaSCrdPTIBbd
Zq5kPAb+lf+46exhvT2JeCwrpuofPXzMUp4aq8cqlVt5T1jKU8Mj3nnT6wuS
p0Zw+F7YY35OngYTTfmO5slB8jQIWV0t9f6X5GnxWTC21U28Ik8Lk7L7d0Q1
RJ4W335Kz04VvyYvG98LN+tavcPkZeO4vWn+T1mYPB28gf0nXhSOkKfDQN7V
wIPtEfJ0uHbUHj8/NkqegCt/S9ejNWPkCcgtjxdkchHy9HC35S/cbY+Qp8dl
a4zv2C2Rp8f8TJWfFyXmTnoGcBl7PtqWJPIMaFicXrl/MkqeEeMXKxZLO6Lk
GdElfN3MWoiSZ0TF+7JuUWDkmTDrOyOUnGbkmfChP2tQcYORZ0bzW90+V4iR
Z8bUkuXg2TlGnhnV54aCsV9pLweSs9ZdkCmTl4Mvk2JgFy+TZ8H6Rtdan0Em
z4LVkH7aZZPJs8DZ+XTvsl0mzwpe4dN8yk17Vniu39qyO9KeDfFDMbZxWGY7
OV8ebQ==
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{4., 0.},
  Method->{},
  PlotRange->{{4., 8.}, {-0.1262556298251899, 0.011241573255480308`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.08, 0.08}, {0.0027499440616134043`, 
   0.0027499440616134043`}}]], "Output",
 CellChangeTimes->{{3.729272362415473*^9, 3.7292724622683*^9}, 
   3.729272523950469*^9, {3.729516996951193*^9, 3.729517052028171*^9}, {
   3.729517184549604*^9, 3.729517192401341*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "find\[LetterSpace]stagnation\[LetterSpace]point\[LetterSpace]bisection", 
   "[", 
   RowBox[{"\[Gamma]val_", ",", "\[Eta]val_", ",", "ileft_", ",", "iright_"}],
    "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "left", ",", "right", ",", "vl", ",", "vr", ",", "i", ",", "middle", ",",
       "vm"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"left", "=", "ileft"}], ";", "\[IndentingNewLine]", 
     RowBox[{"right", "=", "iright"}], ";", "\[IndentingNewLine]", 
     RowBox[{"vl", "=", 
      RowBox[{"wrapper", "[", "left", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vr", "=", 
      RowBox[{"wrapper", "[", "right", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Assert", "[", 
      RowBox[{
       RowBox[{"vl", "*", "vr"}], "<", "0"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<", "10"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"middle", "=", 
         RowBox[{"0.5", "*", 
          RowBox[{"(", 
           RowBox[{"left", "+", "right"}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"vm", "=", 
         RowBox[{"wrapper", "[", "middle", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"vm", "<", "0"}], ",", 
          RowBox[{"right", "=", "middle"}], ",", 
          RowBox[{"left", "=", "middle"}]}], "]"}]}]}], "\[IndentingNewLine]",
       "]"}], ";", "\[IndentingNewLine]", "middle"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"my\[LetterSpace]\[Xi]st", "=", 
  RowBox[{
  "find\[LetterSpace]stagnation\[LetterSpace]point\[LetterSpace]bisection", 
   "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], ",", "2.9", ",", "4", ",", "8"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.729270983986045*^9, 3.72927118034558*^9}, {
  3.729271219550305*^9, 3.729271276608301*^9}, {3.7292724754954367`*^9, 
  3.7292725180631247`*^9}, {3.7295172032730923`*^9, 3.729517219080187*^9}, {
  3.7295174696569757`*^9, 3.72951747972021*^9}}],

Cell[BoxData["4.0859375`"], "Output",
 CellChangeTimes->{{3.729272520300521*^9, 3.729272527001548*^9}, 
   3.729517219715473*^9, 3.7295174816161537`*^9}]
}, Open  ]],

Cell["\<\
Now that we have the stagnation point, we can reconstruct the entire profile\
\>", "Text",
 CellChangeTimes->{{3.729517308300027*^9, 3.729517332015727*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{
   "shoot\[LetterSpace]outside\[LetterSpace]in\[LetterSpace]supersonic", "[", 
    
    RowBox[{
     RowBox[{"4", "/", "3"}], ",", "2.9", ",", "my\[LetterSpace]\[Xi]st"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_stagnation2outer_sonic.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729517811276717*^9, 3.729517811696678*^9}, {
  3.729517886524498*^9, 3.729517918613329*^9}, {3.7295179662526217`*^9, 
  3.72951808497908*^9}, {3.729518295808043*^9, 3.729518360434783*^9}, {
  3.729518444816001*^9, 3.729518476134206*^9}, {3.7295185201899023`*^9, 
  3.729518520309836*^9}}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_stagnation2outer_sonic.csv\"\>"]\
, "Output",
 CellChangeTimes->{3.72951831021206*^9, 3.72951836253561*^9, 
  3.72951847687197*^9, 3.72951852107654*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"shoot\[LetterSpace]inside\[LetterSpace]out", "[", 
    RowBox[{
     RowBox[{"4", "/", "3"}], ",", "2.9", ",", "my\[LetterSpace]\[Xi]st"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_inner_sonic2stagnation.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729517811276717*^9, 3.729517811696678*^9}, {
  3.729517886524498*^9, 3.729517918613329*^9}, {3.7295179662526217`*^9, 
  3.72951808497908*^9}, {3.729518295808043*^9, 3.729518360434783*^9}, {
  3.729518444816001*^9, 3.729518476134206*^9}, {3.729518514957999*^9, 
  3.729518535061182*^9}}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_inner_sonic2stagnation.csv\"\>"]\
, "Output",
 CellChangeTimes->{3.729518535934223*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"temp", ",", "ode", ",", 
      RowBox[{"\[Gamma]val", "=", 
       RowBox[{"4", "/", "3"}]}], ",", 
      RowBox[{"\[Eta]val", "=", "2.9"}], ",", "\[Xi]so", ",", "\[Xi]start", 
      ",", "\[Xi]end"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Xi]so", "=", 
      RowBox[{
      "calc\[LetterSpace]outer\[LetterSpace]sonic\[LetterSpace]point", "[", 
       RowBox[{
       "\[Gamma]val", ",", "\[Eta]val", ",", "my\[LetterSpace]\[Xi]st"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
     "temp", "=", "mach\[LetterSpace]number\[LetterSpace]derivative"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
         RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
         RowBox[{"\[Xi]s", "\[Rule]", " ", "my\[LetterSpace]\[Xi]st"}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ode", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "'"}], "[", "\[Xi]", "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"temp", "/.", 
         RowBox[{"m", "\[Rule]", " ", 
          RowBox[{"m", "[", "\[Xi]", "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Xi]start", "=", 
      RowBox[{"\[Xi]so", "*", "1.01"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]end", "=", 
      RowBox[{"\[Xi]so", "*", "10"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "\[Xi]", "]"}], "/.", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ode", ",", 
           RowBox[{
            RowBox[{"m", "[", "\[Xi]start", "]"}], "\[Equal]", "1.01"}]}], 
          "}"}], ",", 
         RowBox[{"m", "[", "\[Xi]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Xi]start", ",", "\[Xi]end"}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_beyond_outer_sonic.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729518604446335*^9, 3.729518640459708*^9}, {
   3.729518694779271*^9, 3.729519035053505*^9}, 3.729522631578578*^9, 
   3.729528857999153*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"22.207107270752953`", ",", "1.01`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24.18375969019918`", ",", "1.044333613784103`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"26.16041210964541`", ",", "1.0800629185996804`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28.13706452909164`", ",", "1.1125320973702788`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.113716948537867`", ",", "1.1422372861704846`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32.090369367984096`", ",", "1.1695752487822808`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"34.06702178743032`", ",", "1.1948657992701146`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"36.04367420687655`", ",", "1.2183700429310218`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"38.020326626322785`", ",", "1.2403036755201413`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"39.99697904576901`", ",", "1.2608467657373117`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"41.973631465215234`", ",", "1.2801510859064182`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"43.95028388466147`", ",", "1.2983455897107543`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"45.9269363041077`", ",", "1.3155407527255079`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"47.90358872355392`", ",", "1.3318318457870744`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49.88024114300015`", ",", "1.347301557200271`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"51.85689356244638`", ",", "1.3620220969602834`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"53.83354598189261`", ",", "1.3760568619361537`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"55.81019840133884`", ",", "1.389461779582375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"57.78685082078506`", ",", "1.402286425679287`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"59.7635032402313`", ",", "1.4145749123289424`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"61.74015565967753`", ",", "1.42636667954933`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"63.71680807912375`", ",", "1.4376971084405714`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"65.69346049856998`", ",", "1.4485980479215546`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"67.67011291801622`", ",", "1.4590982645760566`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"69.64676533746244`", ",", "1.4692238495652725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"71.62341775690867`", ",", "1.4789984004794976`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"73.60007017635489`", ",", "1.4884436042836258`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75.57672259580113`", ",", "1.4975790434338745`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"77.55337501524735`", ",", "1.5064228922208451`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"79.53002743469358`", ",", "1.514991616888978`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"81.5066798541398`", ",", "1.5233005034918203`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"83.48333227358604`", ",", "1.5313635973240105`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"85.45998469303227`", ",", "1.5391938303809765`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"87.4366371124785`", ",", "1.5468032719556017`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"89.41328953192472`", ",", "1.5542029817875613`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"91.38994195137096`", ",", "1.561403347608105`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"93.36659437081718`", ",", "1.5684139616980235`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95.34324679026341`", ",", "1.5752437811642144`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"97.31989920970965`", ",", "1.581901131941872`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"99.29655162915587`", ",", "1.5883938879164476`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"101.2732040486021`", ",", "1.5947292722134832`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"103.24985646804832`", ",", "1.6009142236265232`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"105.22650888749455`", ",", "1.6069550704882825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"107.20316130694079`", ",", "1.6128579322364966`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"109.17981372638701`", ",", "1.6186284078022972`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"111.15646614583324`", ",", "1.6242718954169055`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"113.13311856527947`", ",", "1.629793391139467`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"115.1097709847257`", ",", "1.635197664885711`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"117.08642340417192`", ",", "1.6404892008945462`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"119.06307582361815`", ",", "1.645672228370697`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"121.03972824306437`", ",", "1.6507507863759778`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123.01638066251061`", ",", "1.6557286443083061`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"124.99303308195684`", ",", "1.6606094664154438`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"126.96968550140306`", ",", "1.6653965949519918`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"128.9463379208493`", ",", "1.670093300632967`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"130.9229903402955`", ",", "1.674702732312031`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"132.89964275974174`", ",", "1.6792277491734897`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"134.87629517918796`", ",", "1.6836711680721577`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"136.8529475986342`", ",", "1.6880357006219042`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"138.82960001808044`", ",", "1.6923238212541973`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"140.80625243752667`", ",", "1.696537971625305`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"142.7829048569729`", ",", "1.7006805021767293`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"144.75955727641912`", ",", "1.7047535679065833`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"146.73620969586534`", ",", "1.7087592981778421`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"148.71286211531157`", ",", "1.7126997426722645`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"150.6895145347578`", ",", "1.716576788930737`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"152.66616695420402`", ",", "1.7203923043296268`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"154.64281937365024`", ",", "1.7241480862436134`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"156.61947179309647`", ",", "1.7278457966302596`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"158.59612421254272`", ",", "1.7314870814491972`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"160.57277663198894`", ",", "1.7350735249099087`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"162.54942905143517`", ",", "1.7386065975216398`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"164.5260814708814`", ",", "1.7420877580181573`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"166.50273389032762`", ",", "1.7455184227450602`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"168.47938630977384`", ",", "1.748899882541967`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"170.45603872922007`", ",", "1.7522334081859967`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"172.43269114866632`", ",", "1.755520269999191`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"174.40934356811255`", ",", "1.7587616818366092`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"176.38599598755877`", ",", "1.7619587485280699`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"178.362648407005`", ",", "1.7651125625960191`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"180.33930082645122`", ",", "1.7682242163584767`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"182.31595324589745`", ",", "1.7712947598273248`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"184.29260566534367`", ",", "1.7743251505873463`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"186.2692580847899`", ",", "1.7773163341450897`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"188.24591050423612`", ",", "1.7802692559299846`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"190.22256292368237`", ",", "1.7831848297817794`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192.1992153431286`", ",", "1.786063890993326`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"194.17586776257482`", ",", "1.7889072629768483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"196.15252018202105`", ",", "1.791715769122763`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"198.12917260146727`", ",", "1.794490209184265`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"200.1058250209135`", ",", "1.7972313159852822`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"202.08247744035972`", ",", "1.7999398107074038`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"204.05912985980598`", ",", "1.8026164145291148`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"206.0357822792522`", ",", "1.805261830821482`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"208.01243469869843`", ",", "1.807876706002035`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"209.98908711814465`", ",", "1.8104616752768092`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"211.96573953759088`", ",", "1.8130173738513273`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"213.9423919570371`", ",", "1.8155444228113522`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"215.91904437648333`", ",", "1.8180433948230434`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"217.89569679592955`", ",", "1.8205148522876407`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"219.87234921537578`", ",", "1.822959357606383`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.729518814191177*^9, 3.729518826808366*^9}, {
   3.7295188831730623`*^9, 3.729518971963575*^9}, 3.729519035751356*^9, 
   3.729522631914637*^9}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_beyond_outer_sonic.csv\"\>"], \
"Output",
 CellChangeTimes->{{3.729518814191177*^9, 3.729518826808366*^9}, {
   3.7295188831730623`*^9, 3.729518971963575*^9}, 3.729519035751356*^9, 
   3.729522632000371*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"temp", ",", "ode", ",", 
      RowBox[{"\[Gamma]val", "=", 
       RowBox[{"4", "/", "3"}]}], ",", 
      RowBox[{"\[Eta]val", "=", "2.9"}], ",", "\[Xi]si", ",", "\[Xi]start", 
      ",", "\[Xi]end"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Xi]si", "=", 
      RowBox[{
      "calc\[LetterSpace]inner\[LetterSpace]sonic\[LetterSpace]point", "[", 
       RowBox[{
       "\[Gamma]val", ",", "\[Eta]val", ",", "my\[LetterSpace]\[Xi]st"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
     "temp", "=", "mach\[LetterSpace]number\[LetterSpace]derivative"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp", " ", "=", " ", 
      RowBox[{"temp", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Gamma]", "\[Rule]", "\[Gamma]val"}], ",", 
         RowBox[{"\[Eta]", "\[Rule]", "\[Eta]val"}], ",", 
         RowBox[{"\[Xi]s", "\[Rule]", " ", "my\[LetterSpace]\[Xi]st"}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ode", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "'"}], "[", "\[Xi]", "]"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{"temp", "/.", 
         RowBox[{"m", "\[Rule]", " ", 
          RowBox[{"m", "[", "\[Xi]", "]"}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Xi]start", "=", 
      RowBox[{"\[Xi]si", "/", "10"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Xi]end", "=", 
      RowBox[{"\[Xi]si", "*", "0.99"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "\[Xi]", "]"}], "/.", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ode", ",", 
           RowBox[{
            RowBox[{"m", "[", "\[Xi]end", "]"}], "\[Equal]", 
            RowBox[{"-", "1.01"}]}]}], "}"}], ",", 
         RowBox[{"m", "[", "\[Xi]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Xi]", ",", "\[Xi]start", ",", "\[Xi]end"}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{"sol", "[", 
    RowBox[{"[", 
     RowBox[{"0", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"sol", "/.", 
       RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax", ",", 
      FractionBox[
       RowBox[{"xmax", "-", "xmin"}], "100"]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<mach_beyond_inner_sonic.csv\>\""}], "]"}], ",", "%"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.729518604446335*^9, 3.729518640459708*^9}, {
  3.729518694779271*^9, 3.729519035053505*^9}, {3.729519115076941*^9, 
  3.729519194996291*^9}, {3.729522622403668*^9, 3.729522628377308*^9}}],

Cell[BoxData["\<\"/home/ayalin/Downloads/mach_beyond_inner_sonic.csv\"\>"], \
"Output",
 CellChangeTimes->{{3.7295191245107193`*^9, 3.729519195307405*^9}, {
  3.7295226240470877`*^9, 3.729522628759182*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"integral\[LetterSpace]energy\[LetterSpace]conservation", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"u", "\[Rule]", " ", 
    RowBox[{"m", " ", "c"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"c", "\[Rule]", " ", 
    RowBox[{"cc", " ", "vw"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"rs", "\[Rule]", " ", 
    RowBox[{"\[Xi]s", " ", "*", 
     FractionBox["GM", 
      SuperscriptBox["vw", "2"]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"\[Xi]", "*", 
     FractionBox["GM", 
      SuperscriptBox["vw", "2"]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PowerExpand", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox["cc", "2"], "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "cc"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"G", ">", "0"}], ",", 
      RowBox[{"M", ">", "0"}], ",", 
      RowBox[{"\[Gamma]", ">", "1"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Xi]", "\[Rule]", "r"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Xi]s", "\[Rule]", "rs"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", " ", "/.", " ", 
   RowBox[{"\[Eta]", "\[Rule]", "n"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FortranForm", "[", "%", "]"}]}], "Input",
 CellChangeTimes->{{3.729523289260954*^9, 3.729523445522003*^9}, {
  3.7295234999444036`*^9, 3.729523533947886*^9}}],

Cell["\<\
((-1 + g)*(-(r**(1 + n)*(6 + n*(-2 + rs) - 2*rs)*rs**2) - 2*(-2 + \
n)*r**n*rs**3 + 2*r**3*rs**n + (-2 + n)*r**4*rs**n))/((2 + (-1 + g)*m**2)*(-2 \
+ n)*r*(-(r**n*rs**3) + r**3*rs**n))\
\>", "Output",
 CellChangeTimes->{{3.7295232906949587`*^9, 3.729523446140245*^9}, {
  3.729523505688101*^9, 3.729523534243265*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{2558, 1524},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 108, 1, 24, "Chapter"],
Cell[669, 23, 102, 1, 30, "Text"],
Cell[774, 26, 544, 14, 58, "Input"],
Cell[1321, 42, 108, 1, 30, "Text"],
Cell[1432, 45, 729, 19, 57, "Input"],
Cell[2164, 66, 108, 1, 30, "Text"],
Cell[2275, 69, 1481, 39, 59, "Input"],
Cell[3759, 110, 100, 1, 30, "Text"],
Cell[3862, 113, 334, 8, 32, "Input"],
Cell[4199, 123, 104, 1, 30, "Text"],
Cell[4306, 126, 1862, 56, 187, "Input"],
Cell[6171, 184, 151, 2, 24, "Chapter"],
Cell[6325, 188, 95, 1, 30, "Text"],
Cell[6423, 191, 260, 6, 57, "Input"],
Cell[6686, 199, 95, 1, 30, "Text"],
Cell[6784, 202, 526, 13, 77, "Input"],
Cell[7313, 217, 162, 2, 24, "Chapter"],
Cell[7478, 221, 3281, 95, 416, "Input"],
Cell[10762, 318, 107, 1, 24, "Chapter"],
Cell[10872, 321, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[11000, 326, 783, 22, 145, "Input"],
Cell[11786, 350, 1182, 25, 55, "Output"]
}, Open  ]],
Cell[12983, 378, 92, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[13100, 383, 1293, 37, 187, "Input"],
Cell[14396, 422, 707, 10, 32, "Output"]
}, Open  ]],
Cell[15118, 435, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[15246, 440, 1680, 49, 270, "Input"],
Cell[16929, 491, 2017, 54, 62, "Output"]
}, Open  ]],
Cell[18961, 548, 94, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19080, 553, 3580, 103, 398, "Input"],
Cell[22663, 658, 918, 12, 32, "Output"]
}, Open  ]],
Cell[23596, 673, 122, 1, 24, "Chapter"],
Cell[23721, 676, 1083, 31, 155, "Input"],
Cell[24807, 709, 832, 23, 121, "Input"],
Cell[25642, 734, 261, 3, 24, "Chapter"],
Cell[CellGroupData[{
Cell[25928, 741, 248, 6, 32, "Input"],
Cell[26179, 749, 890, 19, 32, "Output"]
}, Open  ]],
Cell[27084, 771, 2825, 82, 323, "Input"],
Cell[29912, 855, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[30036, 860, 823, 27, 123, "Input"],
Cell[30862, 889, 374, 6, 32, "Output"]
}, Open  ]],
Cell[31251, 898, 1256, 35, 144, "Input"],
Cell[32510, 935, 130, 1, 30, "Text"],
Cell[32643, 938, 738, 18, 77, "Input"],
Cell[33384, 958, 141, 1, 25, "Chapter"],
Cell[33528, 961, 2756, 84, 164, "Input"],
Cell[36287, 1047, 1200, 36, 155, "Input"],
Cell[37490, 1085, 2872, 82, 256, "Input"],
Cell[40365, 1169, 253, 5, 25, "Chapter"],
Cell[40621, 1176, 2871, 87, 186, "Input"],
Cell[43495, 1265, 1199, 35, 155, "Input"],
Cell[44697, 1302, 3514, 97, 289, "Input"],
Cell[48214, 1401, 140, 1, 25, "Chapter"],
Cell[48357, 1404, 5280, 155, 391, "Input"],
Cell[53640, 1561, 139, 1, 25, "Chapter"],
Cell[53782, 1564, 6823, 194, 368, "Input"],
Cell[60608, 1760, 118, 1, 25, "Chapter"],
Cell[60729, 1763, 6690, 208, 544, "Input"],
Cell[67422, 1973, 1555, 47, 177, "Input"],
Cell[CellGroupData[{
Cell[69002, 2024, 903, 23, 147, "Input"],
Cell[69908, 2049, 565, 16, 34, "Output"],
Cell[70476, 2067, 264, 3, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70777, 2075, 561, 14, 99, "Input"],
Cell[71341, 2091, 258, 6, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71636, 2102, 406, 10, 81, "Input"],
Cell[72045, 2114, 214, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72296, 2124, 327, 8, 81, "Input"],
Cell[72626, 2134, 177, 3, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72840, 2142, 667, 17, 148, "Input"],
Cell[73510, 2161, 233, 5, 46, "Output"]
}, Open  ]],
Cell[73758, 2169, 107, 1, 24, "Chapter"],
Cell[73868, 2172, 617, 16, 104, "Input"],
Cell[74488, 2190, 1660, 46, 165, "Input"],
Cell[76151, 2238, 176, 4, 32, "Text"],
Cell[76330, 2244, 1220, 31, 193, "Input"],
Cell[77553, 2277, 943, 24, 121, "Input"],
Cell[CellGroupData[{
Cell[78521, 2305, 1019, 25, 165, "Input"],
Cell[79543, 2332, 824, 23, 51, "Output"]
}, Open  ]],
Cell[80382, 2358, 140, 2, 24, "Chapter"],
Cell[80525, 2362, 807, 21, 147, "Input"],
Cell[81335, 2385, 1658, 47, 236, "Input"],
Cell[82996, 2434, 494, 12, 55, "Input"],
Cell[83493, 2448, 1412, 38, 258, "Input"],
Cell[84908, 2488, 96, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[85029, 2493, 2106, 63, 305, "Input"],
Cell[87138, 2558, 662, 10, 32, "Output"]
}, Open  ]],
Cell[87815, 2571, 108, 1, 24, "Chapter"],
Cell[87926, 2574, 2577, 47, 143, "Input"],
Cell[90506, 2623, 100, 1, 24, "Chapter"],
Cell[CellGroupData[{
Cell[90631, 2628, 2015, 53, 149, "Input"],
Cell[92649, 2683, 30486, 518, 385, 19950, 344, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[123150, 3204, 109, 1, 24, "Chapter"],
Cell[123262, 3207, 3845, 108, 420, "Input"],
Cell[CellGroupData[{
Cell[127132, 3319, 104, 1, 92, "Title"],
Cell[127239, 3322, 105, 1, 50, "Subtitle"],
Cell[127347, 3325, 110, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[127482, 3330, 2228, 54, 304, "Input"],
Cell[129713, 3386, 335, 4, 32, "Output"]
}, Open  ]],
Cell[130063, 3393, 163, 3, 30, "Text"],
Cell[130229, 3398, 457, 13, 74, "Input"],
Cell[130689, 3413, 162, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[130876, 3419, 3211, 84, 237, "Input"],
Cell[134090, 3505, 2493, 48, 243, "Output"]
}, Open  ]],
Cell[136598, 3556, 160, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[136783, 3562, 2722, 71, 209, "Input"],
Cell[139508, 3635, 3283, 61, 240, "Output"]
}, Open  ]],
Cell[142806, 3699, 104, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[142935, 3704, 2369, 56, 210, "Input"],
Cell[145307, 3762, 164, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145508, 3769, 1101, 26, 121, "Input"],
Cell[146612, 3797, 1402, 28, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148051, 3830, 2198, 55, 297, "Input"],
Cell[150252, 3887, 304, 4, 32, "Output"]
}, Open  ]],
Cell[150571, 3894, 113, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[150709, 3899, 1607, 44, 147, "Input"],
Cell[152319, 3945, 269, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152625, 3955, 1586, 43, 147, "Input"],
Cell[154214, 4000, 156, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154407, 4007, 3433, 93, 345, "Input"],
Cell[157843, 4102, 150, 2, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158030, 4109, 112, 1, 29, "Subsubtitle"],
Cell[CellGroupData[{
Cell[158167, 4114, 1781, 41, 128, "Input"],
Cell[159951, 4157, 310, 4, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160298, 4166, 241, 4, 32, "Input"],
Cell[160542, 4172, 112, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160691, 4178, 3339, 86, 237, "Input"],
Cell[164033, 4266, 2683, 51, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166753, 4322, 703, 19, 55, "Input"],
Cell[167459, 4343, 2389, 47, 243, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169885, 4395, 2577, 59, 210, "Input"],
Cell[172465, 4456, 197, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172699, 4464, 1247, 28, 121, "Input"],
Cell[173949, 4494, 761, 14, 23, "Message"],
Cell[174713, 4510, 763, 14, 23, "Message"],
Cell[175479, 4526, 761, 14, 23, "Message"],
Cell[176243, 4542, 605, 12, 23, "Message"],
Cell[176851, 4556, 1328, 27, 220, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178216, 4588, 2200, 55, 297, "Input"],
Cell[180419, 4645, 153, 2, 32, "Output"]
}, Open  ]],
Cell[180587, 4650, 166, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[180778, 4657, 1523, 44, 147, "Input"],
Cell[182304, 4703, 198, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182539, 4711, 1488, 42, 147, "Input"],
Cell[184030, 4755, 133, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184200, 4762, 3321, 92, 345, "Input"],
Cell[187524, 4856, 9725, 208, 187, "Output"],
Cell[197252, 5066, 253, 4, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197542, 5075, 3382, 92, 345, "Input"],
Cell[200927, 5169, 206, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201170, 5177, 2052, 57, 373, "Input"],
Cell[203225, 5236, 327, 6, 46, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

